@@ -29,8 +29,7 @@ AbstractProjectItem::AbstractProjectItem(PROJECTITEMTYPE type, QString id, const
     , m_outPoint()
     , m_date()
     , m_binId(std::move(id))
-    , m_totalUsage(0)
-    , m_currentSequenceUsage(0)
+    , m_usage(0)
     , m_AudioUsage(0)
     , m_rating(0)
     , m_clipStatus(FileStatus::StatusReady)
@@ -54,44 +53,37 @@ std::shared_ptr<AbstractProjectItem> AbstractProjectItem::parent() const
     return std::static_pointer_cast<AbstractProjectItem>(m_parentItem.lock());
 }
 
-void AbstractProjectItem::setRefCount(uint count, uint totalCount)
+void AbstractProjectItem::setRefCount(uint count, uint audioCount)
 {
-    if (count == totalCount) {
-        if (count == 0) {
-            m_usageText.clear();
-        } else {
-            m_usageText = QString::number(count);
-        }
-    } else {
-        m_usageText = QString("%1|%2").arg(count).arg(totalCount);
-    }
-    m_currentSequenceUsage = count;
-    m_totalUsage = totalCount;
-    m_VideoUsage = count - m_AudioUsage;
-    if (auto ptr = m_model.lock())
-        std::static_pointer_cast<ProjectItemModel>(ptr)->onItemUpdated(
-            std::static_pointer_cast<AbstractProjectItem>(shared_from_this()),
-            {AbstractProjectItem::UsageCount, AbstractProjectItem::VideoUsed, AbstractProjectItem::AudioUsed});
-}
-
-uint AbstractProjectItem::refCount() const
-{
-    return m_totalUsage;
-}
-
-void AbstractProjectItem::addRef()
-{
-    m_currentSequenceUsage++;
-    m_totalUsage++;
+    m_usage = count;
+    m_AudioUsage = audioCount;
     if (auto ptr = m_model.lock())
         std::static_pointer_cast<ProjectItemModel>(ptr)->onItemUpdated(std::static_pointer_cast<AbstractProjectItem>(shared_from_this()),
                                                                        {AbstractProjectItem::UsageCount});
 }
 
-void AbstractProjectItem::removeRef()
+uint AbstractProjectItem::refCount() const
 {
-    m_currentSequenceUsage--;
-    m_totalUsage--;
+    return m_usage;
+}
+
+void AbstractProjectItem::addRef(bool isAudio)
+{
+    m_usage++;
+    if (isAudio) {
+        m_AudioUsage++;
+    }
+    if (auto ptr = m_model.lock())
+        std::static_pointer_cast<ProjectItemModel>(ptr)->onItemUpdated(std::static_pointer_cast<AbstractProjectItem>(shared_from_this()),
+                                                                       {AbstractProjectItem::UsageCount});
+}
+
+void AbstractProjectItem::removeRef(bool isAudio)
+{
+    m_usage--;
+    if (isAudio) {
+        m_AudioUsage--;
+    }
     if (auto ptr = m_model.lock())
         std::static_pointer_cast<ProjectItemModel>(ptr)->onItemUpdated(std::static_pointer_cast<AbstractProjectItem>(shared_from_this()),
                                                                        {AbstractProjectItem::UsageCount});
@@ -153,13 +145,10 @@ QVariant AbstractProjectItem::getData(DataType type) const
         data = QVariant(m_date);
         break;
     case UsageCount:
-        data = QVariant(m_usageText);
+        data = QVariant(m_usage);
         break;
-    case AudioUsed:
-        data = QVariant(m_AudioUsage > 0);
-        break;
-    case VideoUsed:
-        data = QVariant(m_VideoUsage > 0);
+    case AudioUsageCount:
+        data = QVariant(m_AudioUsage);
         break;
     case ItemTypeRole:
         data = QVariant(m_itemType);
@@ -209,6 +198,17 @@ QVariant AbstractProjectItem::getData(DataType type) const
         }*/
         data = QVariant(true);
         break;
+    case SequenceFolder:
+        if (itemType() == FolderItem) {
+            if (auto ptr = m_model.lock()) {
+                if (m_binId.toInt() == std::static_pointer_cast<ProjectItemModel>(ptr)->defaultSequencesFolder()) {
+                    data = QVariant(true);
+                    break;
+                }
+            }
+        }
+        data = QVariant(false);
+        break;
     case ClipStatus:
         data = QVariant(m_clipStatus);
         break;
