@@ -324,12 +324,21 @@ public:
     void loadBinProperties(const QStringList &foldersToExpand, int zoomLevel = -1);
     /** @brief gets a QList of all clips used in timeline */
     QList<int> getUsedClipIds();
+    /** @brief Register a new timeline clip
+     * @param uuid the uuid of the new playlist (equals the uuid of the timelinemodel)
+     * @param id the bin id of the clip
+     */
+    void registerSequence(const QUuid uuid, const QString id);
     /** @brief Update a new timeline clip when it has been changed
      * @param uuid the uuid of the timeline clip that was changed
      * @param id the updated duration of the timeline clip
      * * @param current the uuid of the currently active timeline
      */
     void updateSequenceClip(const QUuid &uuid, int duration, int pos);
+    /** @brief Returns the bin id of the clip managing a timeline sequence changed
+     * @param uuid the uuid of the timeline clip
+     */
+    const QString sequenceBinId(const QUuid &uuid);
     /** @brief Update a sequence AV info (has audio/video) */
     void updateSequenceAVType(const QUuid &uuid, int tracksCount);
 
@@ -370,6 +379,8 @@ private Q_SLOTS:
     void slotReloadClip();
     /** @brief Replace clip with another file */
     void slotReplaceClip();
+    /** @brief Replace audio or video component in timeline with another file */
+    void slotReplaceClipInTimeline();
     /** @brief Set sorting column */
     void slotSetSorting();
     /** @brief Show/hide date column */
@@ -443,8 +454,8 @@ public Q_SLOTS:
     /** @brief Start a filter job requested by a filter applied in timeline */
     void slotStartFilterJob(const ItemInfo &info, const QString &id, QMap<QString, QString> &filterParams, QMap<QString, QString> &consumerParams,
                             QMap<QString, QString> &extraParams);
-    void slotItemDropped(const QStringList ids, const QModelIndex parent);
-    const QString slotUrlsDropped(const QList<QUrl> urls, const QModelIndex parent);
+    void slotItemDropped(const QStringList &ids, const QModelIndex &parent);
+    const QString slotItemDropped(const QList<QUrl> &urls, const QModelIndex &parent);
     void slotEffectDropped(const QStringList &effectData, const QModelIndex &parent);
     void slotTagDropped(const QString &tag, const QModelIndex &parent);
     void slotItemEdited(const QModelIndex &, const QModelIndex &, const QVector<int> &);
@@ -463,6 +474,8 @@ public Q_SLOTS:
     void abortOperations();
     void doDisplayMessage(const QString &text, KMessageWidget::MessageType type, const QList<QAction *> &actions = QList<QAction *>(), bool showCloseButton = false, BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
     void doDisplayMessage(const QString &text, KMessageWidget::MessageType type, const QString logInfo);
+    /** @brief Reset all clip usage to 0 */
+    void resetUsageCount();
     /** @brief Select a clip in the Bin from its id. */
     void selectClipById(const QString &id, int frame = -1, const QPoint &zone = QPoint(), bool activateMonitor = true);
     const QString slotAddClipToProject(const QUrl &url);
@@ -479,6 +492,8 @@ public Q_SLOTS:
     void showTitleWidget(const std::shared_ptr<ProjectClip> &clip);
     /** @brief Add a clip in a specially named folder */
     bool addProjectClipInFolder(const QString &path, const QString &sourceClipId, const QString &sourceFolder, const QString &jobId);
+    /** @brief Add a filter with some presets to a clip */
+    void addFilterToClip(const QString &sourceClipId, const QString &filterId, stringMap params);
     /** @brief Check if a clip profile matches project, propose switch otherwise */
     void slotCheckProfile(const QString &binId);
     /** @brief A non seekable clip was added to project, propose transcoding */
@@ -507,6 +522,7 @@ private:
     BinItemDelegate *m_binTreeViewDelegate;
     BinListItemDelegate *m_binListViewDelegate;
     std::unique_ptr<ProjectSortProxyModel> m_proxyModel;
+    QMap<QUuid, QString> m_openedPlaylists;
     QToolBar *m_toolbar;
     KdenliveDoc *m_doc;
     QLineEdit *m_searchLine;
@@ -535,7 +551,8 @@ private:
     QAction *m_openAction;
     QAction *m_editAction;
     QAction *m_reloadAction;
-    QAction *m_replaceAction;
+    QAction *m_replaceAction{nullptr};
+    QAction *m_replaceInTimelineAction{nullptr};
     QAction *m_duplicateAction;
     QAction *m_locateAction;
     QAction *m_proxyAction;
