@@ -112,6 +112,9 @@ public:
     /** @brief Returns the clip type as defined in definitions.h */
     ClipType::ProducerType clipType() const override;
 
+    /** @brief Get the marker model for this clip */
+    std::shared_ptr<MarkerListModel> markerModel();
+
     /** @brief Set rating on item */
     void setRating(uint rating) override;
 
@@ -264,7 +267,7 @@ public:
     /** @brief Return maximum audio level for a stream. */
     int getAudioMax(int stream);
     /** @brief A timeline clip was modified, reload its other timeline instances. */
-    void reloadTimeline(std::shared_ptr<EffectStackModel> stack = nullptr);
+    void reloadTimeline();
     /** @brief Copy sequence clip timewarp producers to a new location (when saving / rendering). */
     void copyTimeWarpProducers(const QDir sequenceFolder, bool copy);
     /** @brief Refresh zones of insertion in timeline. */
@@ -272,7 +275,7 @@ public:
     /** @brief Retuns a list of important enforces parameters in MLT format, for example to disable autorotate. */
     const QStringList enforcedParams() const;
     /** @brief Remove clip references in a timeline. */
-    void purgeReferences(const QUuid &activeUuid, bool deleteClip = true);
+    void purgeReferences(const QUuid &activeUuid);
     /** @brief Check if clip is referenced in a timeline, and return the clip's bin id if it is */
     const QString isReferenced(const QUuid &activeUuid) const;
     const QString baseThumbPath();
@@ -311,7 +314,7 @@ protected:
     /** @brief This is a call-back called by a ClipModel when it is deleted
         @param clipId id of the deleted clip
     */
-    void deregisterTimelineClip(int clipId, bool audioClip, const QUuid &uuid);
+    void deregisterTimelineClip(int clipId, bool audioClip);
     void replaceInTimeline();
     void connectEffectStack() override;
 
@@ -367,7 +370,9 @@ private:
 
     /** @brief This is a helper function that creates the disabled producer. This is a clone of the original one, with audio and video disabled */
     void createDisabledMasterProducer();
-    QMap<QUuid, QList<int>> m_registeredClipsByUuid;
+
+    std::map<int, std::weak_ptr<TimelineModel>> m_registeredClips;
+    uint m_audioCount;
     QTimer m_boundaryTimer;
 
     /** @brief the following holds a producer for each audio clip in the timeline
@@ -385,7 +390,7 @@ private:
     void updateDescription();
 
 Q_SIGNALS:
-    void producerChanged(const QString &, const std::shared_ptr<Mlt::Producer> &);
+    void producerChanged(const QString &, Mlt::Producer prod);
     void refreshPropertiesPanel();
     void refreshAnalysisPanel();
     void refreshClipDisplay();
