@@ -18,6 +18,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QIcon>
 #include <QReadWriteLock>
 #include <QSize>
+#include <QTimer>
 #include <QUuid>
 
 class BinPlaylist;
@@ -51,6 +52,8 @@ public:
 
     friend class ProjectClip;
     friend class ThumbnailCache;
+    /** @brief Timer checking if we have missing clips in the project */
+    QTimer missingClipTimer;
 
     /** @brief Builds the MLT playlist, can only be done after MLT is correctly initialized */
     void buildPlaylist(const QUuid uuid);
@@ -107,7 +110,7 @@ public:
      *  @return A list of invalid sequence clips found in Project Bin (can be caused by 23.04.0 bug)
      */
     QList<QUuid> loadBinPlaylist(Mlt::Service *documentTractor, std::unordered_map<QString, QString> &binIdCorresp, QStringList &expandedFolders,
-                                 const QUuid &activeUuid, int &zoomLevel, QProgressDialog *progressDialog = nullptr);
+                                 int &zoomLevel, QProgressDialog *progressDialog = nullptr);
     void loadTractorPlaylist(Mlt::Tractor documentTractor, std::unordered_map<QString, QString> &binIdCorresp);
 
     /** @brief Save document properties in MLT's bin playlist */
@@ -226,8 +229,6 @@ public:
     const QString getSequenceId(const QUuid &uuid);
     /** @brief Check if we already have a sequence with this uuid */
     bool hasSequenceId(const QUuid &uuid) const;
-    /** @brief Return a project sequence clip from its uuid */
-    std::shared_ptr<ProjectClip> getSequenceClip(const QUuid &uuid);
     /** @brief Returns uuid / bin id of all sequence clips in the project */
     QMap<QUuid, QString> getAllSequenceClips() const;
     /** @brief Return the main project tractor (container of all playlists) */
@@ -243,9 +244,7 @@ public:
     int defaultSequencesFolder() const;
     void setSequencesFolder(int id);
     /** @brief Remove clip references for a timeline. */
-    void removeReferencedClips(const QUuid &uuid, bool onDeletion);
-    /** @brief Check that all sequences are correctly stored in the model */
-    void checkSequenceIntegrity(const QString activeSequenceId);
+    void removeReferencedClips(const QUuid &uuid);
 
 protected:
     bool closing;
@@ -275,6 +274,10 @@ public Q_SLOTS:
     @param data is a definition of the subclips (keys are subclips' names, value are "in:out")*/
     void loadSubClips(const QString &id, const QString &clipData, bool logUndo);
 
+private Q_SLOTS:
+    /** @brief Check how many invalid clips we have. */
+    void slotUpdateInvalidCount();
+
 private:
     /** @brief Return reference to column specific data */
     int mapToColumn(int column) const;
@@ -288,8 +291,6 @@ private:
     std::unique_ptr<FileWatcher> m_fileWatcher;
     std::unordered_map<QString, std::shared_ptr<Mlt::Tractor>> m_extraPlaylists;
     std::shared_ptr<Mlt::Tractor> m_projectTractor;
-    std::map<int, std::shared_ptr<ProjectClip>> m_allClipItems;
-    QList<int> m_allIds;
 
     int m_nextId;
     QIcon m_blankThumb;
@@ -307,8 +308,8 @@ Q_SIGNALS:
     void requestAudioThumbs(const QString &id, long duration);
     // TODO
     void markersNeedUpdate(const QString &id, const QList<int> &);
-    void itemDropped(const QStringList, const QModelIndex);
-    void urlsDropped(const QList<QUrl>, const QModelIndex);
+    void itemDropped(const QStringList &, const QModelIndex &);
+    void itemDropped(const QList<QUrl> &, const QModelIndex &);
     void effectDropped(const QStringList &, const QModelIndex &);
     void addTag(const QString &, const QModelIndex &);
     void addClipCut(const QString &, int, int);
