@@ -130,6 +130,13 @@ bool Core::build(const QString &packageType, bool testMode)
     return true;
 }
 
+void Core::initHeadless(const QUrl &url)
+{
+    MltConnection::construct(QString());
+    m_projectManager = new ProjectManager(this);
+    QMetaObject::invokeMethod(pCore->projectManager(), "slotLoadHeadless", Qt::QueuedConnection, Q_ARG(QUrl, url));
+}
+
 void Core::initGUI(bool inSandbox, const QString &MltPath, const QUrl &Url, const QString &clipsToLoad)
 {
     m_mainWindow = new MainWindow();
@@ -152,9 +159,10 @@ void Core::initGUI(bool inSandbox, const QString &MltPath, const QUrl &Url, cons
     connect(bin, &Bin::requestShowClipProperties, bin, &Bin::showClipProperties);
     connect(m_projectItemModel.get(), &ProjectItemModel::refreshPanel, m_mainWindow->activeBin(), &Bin::refreshPanel);
     connect(m_projectItemModel.get(), &ProjectItemModel::refreshClip, m_mainWindow->activeBin(), &Bin::refreshClip);
-    connect(m_projectItemModel.get(), &ProjectItemModel::itemDropped, m_mainWindow->activeBin(), &Bin::slotItemDropped, Qt::QueuedConnection);
-    connect(m_projectItemModel.get(), &ProjectItemModel::urlsDropped, m_mainWindow->activeBin(), &Bin::slotUrlsDropped, Qt::QueuedConnection);
-
+    connect(m_projectItemModel.get(), static_cast<void (ProjectItemModel::*)(const QStringList &, const QModelIndex &)>(&ProjectItemModel::itemDropped),
+            m_mainWindow->activeBin(), static_cast<void (Bin::*)(const QStringList &, const QModelIndex &)>(&Bin::slotItemDropped));
+    connect(m_projectItemModel.get(), static_cast<void (ProjectItemModel::*)(const QList<QUrl> &, const QModelIndex &)>(&ProjectItemModel::itemDropped),
+            m_mainWindow->activeBin(), static_cast<const QString (Bin::*)(const QList<QUrl> &, const QModelIndex &)>(&Bin::slotItemDropped));
     connect(m_projectItemModel.get(), &ProjectItemModel::effectDropped, m_mainWindow->activeBin(), &Bin::slotEffectDropped);
     connect(m_projectItemModel.get(), &ProjectItemModel::addTag, m_mainWindow->activeBin(), &Bin::slotTagDropped);
     connect(m_projectItemModel.get(), &QAbstractItemModel::dataChanged, m_mainWindow->activeBin(), &Bin::slotItemEdited);
@@ -686,8 +694,6 @@ int Core::getItemPosition(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipPosition(id.itemId);
-        } else {
-            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::TimelineComposition:
@@ -766,8 +772,6 @@ PlaylistState::ClipState Core::getItemState(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipState(id.itemId);
-        } else {
-            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::TimelineComposition:
@@ -792,8 +796,6 @@ int Core::getItemDuration(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipPlaytime(id.itemId);
-        } else {
-            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::TimelineComposition:
@@ -826,8 +828,6 @@ QSize Core::getItemFrameSize(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipFrameSize(id.itemId);
-        } else {
-            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::BinClip:
@@ -965,9 +965,9 @@ void Core::displayMessage(const QString &message, MessageType type, int timeout)
     }
 }
 
-void Core::loadingClips(int count)
+void Core::loadingClips(int count, bool allowInterrupt)
 {
-    Q_EMIT m_mainWindow->displayProgressMessage(i18n("Loading clips"), MessageType::ProcessingJobMessage, count);
+    Q_EMIT m_mainWindow->displayProgressMessage(i18n("Loading clips"), MessageType::ProcessingJobMessage, count, allowInterrupt);
 }
 
 void Core::displayBinMessage(const QString &text, int type, const QList<QAction *> &actions, bool showClose, BinMessage::BinCategory messageCategory)
