@@ -211,6 +211,31 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     // === "More Options" widget ===
     setRescaleEnabled(false);
     m_view.error_box->setVisible(false);
+
+    // Interpolation
+    m_view.interp_type->addItem(i18n("Nearest (fast)"), QStringLiteral("nearest"));
+    m_view.interp_type->addItem(i18n("Bilinear (good)"), QStringLiteral("bilinear"));
+    m_view.interp_type->addItem(i18n("Bicubic (better)"), QStringLiteral("bicubic"));
+    m_view.interp_type->addItem(i18n("Lanczos (best)"), QStringLiteral("hyper"));
+    int ix = m_view.interp_type->findData(KdenliveSettings::renderInterp());
+    if (ix > -1) {
+        m_view.interp_type->setCurrentIndex(ix);
+    }
+    connect(m_view.interp_type, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
+            [&]() { KdenliveSettings::setRenderInterp(m_view.interp_type->currentData().toString()); });
+    // Deinterlacer
+    m_view.deinterlacer_type->addItem(i18n("One Field (fast)"), QStringLiteral("onefield"));
+    m_view.deinterlacer_type->addItem(i18n("Linear Blend (fast)"), QStringLiteral("linearblend"));
+    m_view.deinterlacer_type->addItem(i18n("YADIF - temporal only (good)"), QStringLiteral("yadif-nospatial"));
+    m_view.deinterlacer_type->addItem(i18n("YADIF (better)"), QStringLiteral("yadif"));
+    m_view.deinterlacer_type->addItem(i18n("BWDIF (best)"), QStringLiteral("bwdif"));
+    ix = m_view.deinterlacer_type->findData(KdenliveSettings::renderDeinterlacer());
+    if (ix > -1) {
+        m_view.deinterlacer_type->setCurrentIndex(ix);
+    }
+    connect(m_view.deinterlacer_type, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
+            [&]() { KdenliveSettings::setRenderDeinterlacer(m_view.deinterlacer_type->currentData().toString()); });
+
     m_view.tc_type->addItem(i18n("None"));
     m_view.tc_type->addItem(i18n("Timecode"), QStringLiteral("#timecode#"));
     m_view.tc_type->addItem(i18n("Timecode Non Drop Frame"), QStringLiteral("#smtpe_ndf#"));
@@ -676,7 +701,7 @@ void RenderWidget::slotPrepareExport(bool delayedRendering)
 
     QList<RenderJobItem *> jobList;
     for (auto &job : jobs) {
-        RenderJobItem *renderItem = createRenderJob(job.playlistPath, job.outputPath, job.subtitlePath);
+        RenderJobItem *renderItem = createRenderJob(job);
         if (renderItem != nullptr) {
             jobList << renderItem;
         }
@@ -689,17 +714,17 @@ void RenderWidget::slotPrepareExport(bool delayedRendering)
     checkRenderStatus();
 }
 
-RenderJobItem *RenderWidget::createRenderJob(const QString &playlist, const QString &outputFile, const QString &subtitleFile)
+RenderJobItem *RenderWidget::createRenderJob(const RenderRequest::RenderJob &job)
 {
-    QList<QTreeWidgetItem *> existing = m_view.running_jobs->findItems(outputFile, Qt::MatchExactly, 1);
+    QList<QTreeWidgetItem *> existing = m_view.running_jobs->findItems(job.outputPath, Qt::MatchExactly, 1);
     RenderJobItem *renderItem = nullptr;
     if (!existing.isEmpty()) {
         renderItem = static_cast<RenderJobItem *>(existing.at(0));
         if (renderItem->status() == RUNNINGJOB || renderItem->status() == WAITINGJOB || renderItem->status() == STARTINGJOB) {
             // There is an existing job that is still pending
-            KMessageBox::information(this,
-                                     i18n("There is already a job writing file:<br /><b>%1</b><br />Abort the job if you want to overwrite it…", outputFile),
-                                     i18n("Already running"));
+            KMessageBox::information(
+                this, i18n("There is already a job writing file:<br /><b>%1</b><br />Abort the job if you want to overwrite it…", job.outputPath),
+                i18n("Already running"));
             // focus the running job
             m_view.running_jobs->setCurrentItem(renderItem);
             return nullptr;
@@ -708,17 +733,14 @@ RenderJobItem *RenderWidget::createRenderJob(const QString &playlist, const QStr
         delete renderItem;
         renderItem = nullptr;
     }
-    renderItem = new RenderJobItem(m_view.running_jobs, QStringList() << QString() << outputFile);
+    renderItem = new RenderJobItem(m_view.running_jobs, QStringList() << QString() << job.outputPath);
 
     QDateTime t = QDateTime::currentDateTime();
     renderItem->setData(1, StartTimeRole, t);
     renderItem->setData(1, LastTimeRole, t);
     renderItem->setData(1, LastFrameRole, 0);
-    QStringList argsJob = {QStringLiteral("delivery"), KdenliveSettings::meltpath(), playlist, QStringLiteral("--pid"),
-                           QString::number(QCoreApplication::applicationPid())};
-    if (!subtitleFile.isEmpty()) {
-        argsJob << QStringLiteral("--subtitle") << subtitleFile;
-    }
+    QStringList argsJob = RenderRequest::argsByJob(job);
+
     renderItem->setData(1, ParametersRole, argsJob);
     qDebug() << "* CREATED JOB WITH ARGS: " << argsJob;
     renderItem->setData(1, OpenBrowserRole, m_view.open_browser->isChecked());
@@ -790,7 +812,7 @@ void RenderWidget::startRendering(RenderJobItem *item)
     if (!QProcess::startDetached(KdenliveSettings::kdenliverendererpath(), rendererArgs)) {
         item->setStatus(FAILEDJOB);
     } else {
-        KNotification::event(QStringLiteral("RenderStarted"), i18n("Rendering <i>%1</i> started", item->text(1)), QPixmap(), this);
+        KNotification::event(QStringLiteral("RenderStarted"), i18n("Rendering <i>%1</i> started", item->text(1)), QPixmap());
     }
 }
 
@@ -1040,9 +1062,7 @@ void RenderWidget::refreshParams()
         QStringList speeds = preset->speeds();
         if (m_view.speed->value() < speeds.count()) {
             const QString &speedValue = speeds.at(m_view.speed->value());
-            if (speedValue.contains(QLatin1Char('='))) {
-                m_params.insert(speedValue.section(QLatin1Char('='), 0, 0), speedValue.section(QLatin1Char('='), 1));
-            }
+            m_params.insertFromString(speedValue, false);
         }
     }
 
@@ -1688,42 +1708,54 @@ void RenderWidget::errorMessage(RenderError type, const QString &message)
 void RenderWidget::projectDurationChanged(int duration)
 {
     if (m_view.render_full->isChecked()) {
-        m_view.infoMessage->setMessageType(KMessageWidget::Information);
-        QString stringDuration = pCore->timecode().getDisplayTimecodeFromFrames(qMax(0, duration + 1), false);
-        m_view.infoMessage->setText(i18n("Render Duration: %1", stringDuration));
-        m_view.infoMessage->show();
+        m_renderDuration = duration + 1;
+        updateRenderInfoMessage();
     }
 }
 
 void RenderWidget::zoneDurationChanged(int duration)
 {
     if (m_view.render_zone->isChecked()) {
-        m_view.infoMessage->setMessageType(KMessageWidget::Information);
-        QString stringDuration = pCore->timecode().getDisplayTimecodeFromFrames(qMax(0, duration), false);
-        m_view.infoMessage->setText(i18n("Render Duration: %1", stringDuration));
-        m_view.infoMessage->show();
+        m_renderDuration = duration;
+        updateRenderInfoMessage();
     }
 }
 
+void RenderWidget::updateRenderInfoMessage()
+{
+    QString stringDuration = pCore->timecode().getDisplayTimecodeFromFrames(qMax(0, m_renderDuration), false);
+    m_view.infoMessage->setMessageType(m_renderDuration <= 0 || m_missingClips > 0 ? KMessageWidget::Warning : KMessageWidget::Information);
+    if (m_missingClips > 0) {
+        QString infoMessage = i18n("Render Duration: %1. ", stringDuration);
+        if (m_missingUsedClips == m_missingClips) {
+            infoMessage.append(i18np("<b>One missing clip used in the project.</b>", "<b>%1 missing clips used in the project.</b>", m_missingClips));
+        } else if (m_missingUsedClips == 0) {
+            infoMessage.append(i18np("One missing clip (unused).", "%1 missing clips (unused).", m_missingClips));
+        } else {
+            infoMessage.append(i18n("%1 missing clips (<b>%2 used in the project</b>).", m_missingClips, m_missingUsedClips));
+        }
+        m_view.infoMessage->setText(infoMessage);
+    } else {
+        m_view.infoMessage->setText(i18n("Render Duration: %1", stringDuration));
+    }
+    m_view.infoMessage->show();
+}
+
 void RenderWidget::showRenderDuration()
 {
-    m_view.infoMessage->setMessageType(KMessageWidget::Information);
-    int duration = 0;
     if (m_view.render_zone->isChecked()) {
         Monitor *pMon = pCore->getMonitor(Kdenlive::ProjectMonitor);
-        duration = pMon->getZoneEnd() - pMon->getZoneStart();
+        m_renderDuration = pMon->getZoneEnd() - pMon->getZoneStart();
     } else if (m_view.render_guide->isChecked()) {
         double fps = pCore->getCurrentProfile()->fps();
         double guideStart = m_view.guide_start->itemData(m_view.guide_start->currentIndex()).toDouble();
         double guideEnd = m_view.guide_end->itemData(m_view.guide_end->currentIndex()).toDouble();
-        duration = int(GenTime(guideEnd).frames(fps)) - int(GenTime(guideStart).frames(fps));
+        m_renderDuration = int(GenTime(guideEnd).frames(fps)) - int(GenTime(guideStart).frames(fps));
     } else {
         // rendering full project
-        duration = pCore->projectDuration();
+        m_renderDuration = pCore->projectDuration();
     }
-    QString stringDuration = pCore->timecode().getDisplayTimecodeFromFrames(qMax(0, duration), false);
-    m_view.infoMessage->setText(i18n("Render Duration: %1", stringDuration));
-    m_view.infoMessage->show();
+    updateRenderInfoMessage();
 }
 
 void RenderWidget::updateProxyConfig(bool enable)
@@ -1800,9 +1832,12 @@ void RenderWidget::prepareJobContextMenu(const QPoint &pos)
         return;
     }
     QMenu menu(this);
-    QAction *newAct = new QAction(i18n("Add to current project"), this);
+    QAction *newAct = new QAction(i18n("Add to Current Project"), this);
     connect(newAct, &QAction::triggered, [&, renderItem]() { pCore->bin()->slotAddClipToProject(QUrl::fromLocalFile(renderItem->text(1))); });
     menu.addAction(newAct);
+    QAction *openContainingFolder = new QAction(i18n("Open Containing Folder"), this);
+    connect(openContainingFolder, &QAction::triggered, [&, renderItem]() { KIO::highlightInFileManager({QUrl::fromLocalFile(renderItem->text(1))}); });
+    menu.addAction(openContainingFolder);
 
     menu.exec(m_view.running_jobs->mapToGlobal(pos));
 }
@@ -1840,3 +1875,10 @@ void RenderWidget::updateMetadataToolTip()
     }
     m_view.edit_metadata->setToolTip(tipText);
 }
+
+void RenderWidget::updateMissingClipsCount(int total, int used)
+{
+    m_missingClips = total;
+    m_missingUsedClips = used;
+    updateRenderInfoMessage();
+}
