@@ -1,7 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2008 Jean-Baptiste Mardelle <jb@kdenlive.org>
-
-SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #pragma once
@@ -16,6 +15,7 @@ class Menu;
 
 #include "bin/model/markerlistmodel.hpp"
 #include "definitions.h"
+#include "render/renderrequest.h"
 #include "renderpresets/renderpresetmodel.hpp"
 #include "renderpresets/tree/renderpresettreemodel.hpp"
 #include "ui_renderwidget_ui.h"
@@ -155,6 +155,8 @@ public Q_SLOTS:
     void resetRenderPath(const QString &path);
     /** @brief Update metadata tooltip with current values. */
     void updateMetadataToolTip();
+    /** @brief Update missing clip info. */
+    void updateMissingClipsCount(int total, int used);
 
 private Q_SLOTS:
     /**
@@ -216,10 +218,12 @@ private:
     bool m_blockProcessing;
     QMap<int, QString> m_errorMessages;
     std::weak_ptr<MarkerListModel> m_guidesModel;
-
     std::shared_ptr<RenderPresetTreeModel> m_treeModel;
     QString m_currentProfile;
     RenderPresetParams m_params;
+    int m_renderDuration{0};
+    int m_missingClips{0};
+    int m_missingUsedClips{0};
 
     Purpose::Menu *m_shareMenu;
     void parseProfiles(const QString &selectedProfile = QString());
@@ -229,7 +233,8 @@ private:
     void startRendering(RenderJobItem *item);
     /** @brief Create a rendering profile from MLT preset. */
     QTreeWidgetItem *loadFromMltPreset(const QString &groupName, const QString &path, QString profileName, bool codecInName = false);
-    RenderJobItem *createRenderJob(const QString &playlist, const QString &outputFile, const QString &subtitleFile = QString());
+    RenderJobItem *createRenderJob(const RenderRequest::RenderJob &job);
+    void updateRenderInfoMessage();
 
 Q_SIGNALS:
     void abortProcess(const QString &url);
