@@ -308,6 +308,22 @@ QVector<QPoint> VideoTextEdit::fullExport()
     return processedZones(zones);
 }
 
+void VideoTextEdit::slotRemoveSilence()
+{
+    for (int i = 0; i < document()->blockCount(); ++i) {
+        QTextBlock block = document()->findBlockByNumber(i);
+        if (block.text() == i18n("No speech")) {
+            QTextCursor curs(block);
+            curs.select(QTextCursor::BlockUnderCursor);
+            curs.removeSelectedText();
+            curs.deleteChar();
+            i--;
+            continue;
+        }
+    }
+    rebuildZones();
+}
+
 void VideoTextEdit::updateLineNumberArea(const QRect &rect, int dy)
 {
     if (dy)
@@ -586,6 +602,11 @@ void VideoTextEdit::mouseMoveEvent(QMouseEvent *e)
     }
 }
 
+void VideoTextEdit::wheelEvent(QWheelEvent *e)
+{
+    QTextEdit::wheelEvent(e);
+}
+
 TextBasedEdit::TextBasedEdit(QWidget *parent)
     : QWidget(parent)
     , m_stt(nullptr)
@@ -707,6 +728,21 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
     button_bookmark->setToolTip(i18n("Add marker for current selection"));
     connect(m_visualEditor->bookmarkAction, &QAction::triggered, this, &TextBasedEdit::addBookmark);
 
+    // Zoom
+    QAction *zoomIn = new QAction(QIcon::fromTheme(QStringLiteral("zoom-in")), i18n("Zoom In"), this);
+    connect(zoomIn, &QAction::triggered, this, &TextBasedEdit::slotZoomIn);
+    QAction *zoomOut = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18n("Zoom Out"), this);
+    connect(zoomOut, &QAction::triggered, this, &TextBasedEdit::slotZoomOut);
+    QAction *removeSilence = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove non speech zones"), this);
+    connect(removeSilence, &QAction::triggered, m_visualEditor, &VideoTextEdit::slotRemoveSilence);
+    // Build menu
+    QMenu *extraMenu = new QMenu(this);
+    extraMenu->addAction(zoomIn);
+    extraMenu->addAction(zoomOut);
+    extraMenu->addSeparator();
+    extraMenu->addAction(removeSilence);
+    subMenu->setMenu(extraMenu);
+
     // Message Timer
     m_hideTimer.setSingleShot(true);
     m_hideTimer.setInterval(5000);
@@ -779,6 +815,37 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
     });
 }
 
+void TextBasedEdit::slotZoomIn()
+{
+    QTextCursor cursor = m_visualEditor->textCursor();
+    m_visualEditor->selectAll();
+    qreal fontSize = QFontInfo(m_visualEditor->currentFont()).pointSizeF() * 1.2;
+    KdenliveSettings::setSubtitleEditFontSize(fontSize);
+    m_visualEditor->setFontPointSize(KdenliveSettings::subtitleEditFontSize());
+    m_visualEditor->setTextCursor(cursor);
+}
+
+void TextBasedEdit::slotZoomOut()
+{
+    QTextCursor cursor = m_visualEditor->textCursor();
+    m_visualEditor->selectAll();
+    qreal fontSize = QFontInfo(m_visualEditor->currentFont()).pointSizeF() / 1.2;
+    fontSize = qMax(fontSize, QFontInfo(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont)).pointSizeF());
+    KdenliveSettings::setSubtitleEditFontSize(fontSize);
+    m_visualEditor->setFontPointSize(KdenliveSettings::subtitleEditFontSize());
+    m_visualEditor->setTextCursor(cursor);
+}
+
+void TextBasedEdit::applyFontSize()
+{
+    if (KdenliveSettings::subtitleEditFontSize() > 0) {
+        QTextCursor cursor = m_visualEditor->textCursor();
+        m_visualEditor->selectAll();
+        m_visualEditor->setFontPointSize(KdenliveSettings::subtitleEditFontSize());
+        m_visualEditor->setTextCursor(cursor);
+    }
+}
+
 void TextBasedEdit::updateEngine()
 {
     delete m_stt;
@@ -854,7 +921,7 @@ void TextBasedEdit::startRecognition()
     m_errorString.clear();
     m_visualEditor->cleanup();
     // m_visualEditor->insertHtml(QStringLiteral("<body>"));
-    m_stt->checkDependencies();
+    m_stt->checkDependencies(false);
     QString modelDirectory;
     QString language;
     QString modelName;
@@ -1102,6 +1169,7 @@ void TextBasedEdit::slotProcessSpeechStatus(int, QProcess::ExitStatus status)
     cur.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
     m_visualEditor->setTextCursor(cur);
     frame_progress->setVisible(false);
+    applyFontSize();
 }
 
 void TextBasedEdit::slotProcessSpeechError()
@@ -1120,20 +1188,72 @@ void TextBasedEdit::slotProcessWhisperSpeech()
 {
     const QString saveData = QString::fromUtf8(m_speechJob->readAllStandardOutput());
     QStringList sentences = saveData.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+    QString sentenceTimings = sentences.takeFirst();
+    if (!sentenceTimings.startsWith(QLatin1Char('['))) {
+        // This is not a timing output
+        if (sentenceTimings.startsWith(QStringLiteral("Detected "))) {
+            showMessage(sentenceTimings, KMessageWidget::Information);
+        }
+        return;
+    }
+    QPair<double, double> sentenceZone;
+    sentenceZone.first = sentenceTimings.section(QLatin1Char('['), 1).section(QLatin1Char('>'), 0, 0).toDouble() + m_clipOffset;
+    sentenceZone.second = sentenceTimings.section(QLatin1Char('>'), 1).section(QLatin1Char(']'), 0, 0).toDouble() + m_clipOffset;
     QTextCursor cursor = m_visualEditor->textCursor();
     QTextCharFormat fmt = cursor.charFormat();
-    QPair<double, double> sentenceZone;
-    for (auto &s : sentences) {
+    QPair<double, double> wordZone;
+    GenTime sentenceStart(sentenceZone.first);
+    if (sentenceStart.frames(pCore->getCurrentFps()) > m_lastPosition + 1) {
+        // Insert space
+        GenTime silenceStart(m_lastPosition, pCore->getCurrentFps());
+        m_visualEditor->moveCursor(QTextCursor::End);
+        fmt.setAnchorHref(QString("%1#%2:%3")
+                              .arg(m_binId)
+                              .arg(silenceStart.seconds())
+                              .arg(GenTime(sentenceStart.frames(pCore->getCurrentFps()) - 1, pCore->getCurrentFps()).seconds()));
         fmt.setAnchor(true);
-        sentenceZone.first = s.section(QLatin1Char('['), 1).section(QLatin1Char('>'), 0, 0).toDouble() + m_clipOffset;
-        sentenceZone.second = s.section(QLatin1Char('>'), 1).section(QLatin1Char(']'), 0, 0).toDouble() + m_clipOffset;
-        qDebug() << "=== GOT SENTENCE: " << sentenceZone;
-        fmt.setAnchorHref(QString("%1#%2:%3").arg(m_binId).arg(sentenceZone.first).arg(sentenceZone.second));
-        cursor.insertText(s.section(QLatin1Char(']'), 1), fmt);
+        cursor.insertText(i18n("No speech"), fmt);
+        fmt.setAnchor(false);
+        m_visualEditor->textCursor().insertBlock(cursor.blockFormat());
+        m_visualEditor->speechZones << QPair<double, double>(silenceStart.seconds(),
+                                                             GenTime(sentenceStart.frames(pCore->getCurrentFps()) - 1, pCore->getCurrentFps()).seconds());
+    }
+    for (auto &s : sentences) {
+        wordZone.first = s.section(QLatin1Char('['), 1).section(QLatin1Char('>'), 0, 0).toDouble() + m_clipOffset;
+        wordZone.second = s.section(QLatin1Char('>'), 1).section(QLatin1Char(']'), 0, 0).toDouble() + m_clipOffset;
+        const QString text = s.section(QLatin1Char(']'), 1);
+        if (text.isEmpty()) {
+            // new section, insert
+            m_visualEditor->textCursor().insertBlock(cursor.blockFormat());
+            m_visualEditor->speechZones << sentenceZone;
+            GenTime lastSentence(sentenceZone.second);
+            GenTime nextSentence(wordZone.first);
+            if (nextSentence.frames(pCore->getCurrentFps()) > lastSentence.frames(pCore->getCurrentFps()) + 1) {
+                // Insert space
+                m_visualEditor->moveCursor(QTextCursor::End);
+                fmt.setAnchorHref(QString("%1#%2:%3")
+                                      .arg(m_binId)
+                                      .arg(lastSentence.seconds())
+                                      .arg(GenTime(nextSentence.frames(pCore->getCurrentFps()) - 1, pCore->getCurrentFps()).seconds()));
+                fmt.setAnchor(true);
+                cursor.insertText(i18n("No speech"), fmt);
+                fmt.setAnchor(false);
+                m_visualEditor->textCursor().insertBlock(cursor.blockFormat());
+                m_visualEditor->speechZones << QPair<double, double>(
+                    lastSentence.seconds(), GenTime(nextSentence.frames(pCore->getCurrentFps()) - 1, pCore->getCurrentFps()).seconds());
+            }
+            sentenceZone = wordZone;
+            continue;
+        }
+        fmt.setAnchor(true);
+        fmt.setAnchorHref(QString("%1#%2:%3").arg(m_binId).arg(wordZone.first).arg(wordZone.second));
+        cursor.insertText(text, fmt);
         fmt.setAnchor(false);
         cursor.insertText(QStringLiteral(" "), fmt);
-        m_visualEditor->textCursor().insertBlock(cursor.blockFormat());
-        m_visualEditor->speechZones << sentenceZone;
+    }
+    m_visualEditor->textCursor().insertBlock(cursor.blockFormat());
+    m_visualEditor->speechZones << sentenceZone;
+    if (sentenceZone.second < m_clipOffset + m_clipDuration) {
     }
     m_visualEditor->repaintLines();
     qDebug() << ":::  " << saveData;
@@ -1323,7 +1443,27 @@ void TextBasedEdit::createSequence()
         showMessage(i18n("No text to export"), KMessageWidget::Information);
         return;
     }
-    qDebug() << ":::::READY TO EXPORT ZONES: " << zones << "\n\n_____________________";
+    QVector<QPoint> mergedZones;
+    int max = zones.count();
+    int current = 0;
+    int referenceStart = zones.at(current).x();
+    int currentEnd = zones.at(current).y();
+    int nextStart = 0;
+    current++;
+    while (current < max) {
+        nextStart = zones.at(current).x();
+        if (nextStart == currentEnd || nextStart == currentEnd + 1) {
+            // Contiguous zones
+            currentEnd = zones.at(current).y();
+            current++;
+            continue;
+        }
+        // Insert zone
+        mergedZones << QPoint(referenceStart, currentEnd);
+        referenceStart = zones.at(current).x();
+        currentEnd = zones.at(current).y();
+        current++;
+    }
     Fun undo = []() { return true; };
     Fun redo = []() { return true; };
     // Create new timeline sequence
@@ -1421,6 +1561,7 @@ void TextBasedEdit::openClip(std::shared_ptr<ProjectClip> clip)
         clipNameLabel->clear();
         m_visualEditor->cleanup();
     }
+    applyFontSize();
 }
 
 void TextBasedEdit::addBookmark()
