@@ -26,7 +26,6 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "mltcontroller/clipcontroller.h"
 #include "profiles/profilemodel.hpp"
 #include "profiles/profilerepository.hpp"
-#include "timeline2/model/builders/meltBuilder.hpp"
 #include "timeline2/model/timelineitemmodel.hpp"
 #include "titler/titlewidget.h"
 #include "transitions/transitionsrepository.hpp"
@@ -249,9 +248,22 @@ DocOpenResult KdenliveDoc::Open(const QUrl &url, const QString &projectFolder, Q
         return result;
     }
 
-    // TODO: DocumentChecker is still tightly coupled to the GUI
     DocumentChecker d(url, domDoc);
-    success = !d.hasErrorInClips();
+
+    if (d.hasErrorInProject()) {
+        if (pCore->window() == nullptr) {
+            qInfo() << "DocumentChecker found some problems in the project:";
+            for (const auto &item : d.resourceItems()) {
+                qInfo() << item;
+                if (item.status == DocumentChecker::MissingStatus::Missing) {
+                    success = false;
+                }
+            }
+        } else {
+            success = d.resolveProblemsWithGUI();
+        }
+    }
+
     if (!success) {
         // Loading aborted
         result.setAborted();
@@ -362,8 +374,10 @@ void KdenliveDoc::initializeProperties(bool newDocument, std::pair<int, int> tra
         sequenceProperties[QStringLiteral("activeTrack")] = QString::number(activeTrack);
         sequenceProperties[QStringLiteral("documentuuid")] = m_uuid.toString();
         m_sequenceProperties.insert(m_uuid, sequenceProperties);
-        // For existing documents, don't define guidesCategories, so that we can use the getDefaultGuideCategories() for backwards compatibility
-        m_documentProperties[QStringLiteral("guidesCategories")] = MarkerListModel::categoriesListToJSon(KdenliveSettings::guidesCategories());
+        if (m_timelines.contains(m_uuid)) {
+            // For existing documents, don't define guidesCategories, so that we can use the getDefaultGuideCategories() for backwards compatibility
+            m_documentProperties[QStringLiteral("guidesCategories")] = getGuideModel(m_uuid)->categoriesListToJSon(KdenliveSettings::guidesCategories());
+        }
     }
 }
 
@@ -372,7 +386,7 @@ const QStringList KdenliveDoc::guidesCategories()
     QStringList categories = getGuideModel(activeUuid)->guideCategoriesToStringList(m_documentProperties.value(QStringLiteral("guidesCategories")));
     if (categories.isEmpty()) {
         const QStringList defaultCategories = getDefaultGuideCategories();
-        m_documentProperties[QStringLiteral("guidesCategories")] = MarkerListModel::categoriesListToJSon(defaultCategories);
+        m_documentProperties[QStringLiteral("guidesCategories")] = getGuideModel(activeUuid)->categoriesListToJSon(defaultCategories);
         return defaultCategories;
     }
     return categories;
@@ -1012,11 +1026,6 @@ bool KdenliveDoc::sequenceThumbRequiresRefresh(const QUuid &uuid) const
     return m_sequenceThumbsNeedsRefresh.contains(uuid);
 }
 
-void KdenliveDoc::setSequenceThumbRequiresUpdate(const QUuid &uuid)
-{
-    m_sequenceThumbsNeedsRefresh.insert(uuid);
-}
-
 void KdenliveDoc::sequenceThumbUpdated(const QUuid &uuid)
 {
     m_sequenceThumbsNeedsRefresh.remove(uuid);
@@ -1272,7 +1281,11 @@ void KdenliveDoc::updateProjectFolderPlacesEntry()
      */
 
     const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/user-places.xbel");
+#if QT_VERSION_MAJOR < 6
     KBookmarkManager *bookmarkManager = KBookmarkManager::managerForExternalFile(file);
+#else
+    std::unique_ptr<KBookmarkManager> bookmarkManager = std::make_unique<KBookmarkManager>(file);
+#endif
     if (!bookmarkManager) {
         return;
     }
@@ -1771,31 +1784,24 @@ void KdenliveDoc::switchProfile(ProfileParam *pf, const QString &clipName)
         profile->m_frame_rate_den = 1;
     } else {
         // Check for 23.98, 29.97, 59.94
-        bool fpsFixed = false;
         if (qFuzzyCompare(fps_int, 23.0)) {
             if (qFuzzyCompare(fps, 23.98) || fps_frac > 0.94) {
                 profile->m_frame_rate_num = 24000;
                 profile->m_frame_rate_den = 1001;
-                fpsFixed = true;
             }
         } else if (qFuzzyCompare(fps_int, 29.0)) {
             if (qFuzzyCompare(fps, 29.97) || fps_frac > 0.94) {
                 profile->m_frame_rate_num = 30000;
                 profile->m_frame_rate_den = 1001;
-                fpsFixed = true;
             }
         } else if (qFuzzyCompare(fps_int, 59.0)) {
             if (qFuzzyCompare(fps, 59.94) || fps_frac > 0.9) {
                 profile->m_frame_rate_num = 60000;
                 profile->m_frame_rate_den = 1001;
-                fpsFixed = true;
             }
-        }
-        if (!fpsFixed) {
+        } else {
             // Unknown profile fps, warn user
-            profile->m_frame_rate_num = qRound(fps);
-            profile->m_frame_rate_den = 1;
-            adjustMessage = i18n("Warning: non standard fps, adjusting to closest integer. ");
+            adjustMessage = i18n("\nWarning: unknown non integer fps, might cause incorrect duration display.");
         }
     }
     QString matchingProfile = ProfileRepository::get()->findMatchingProfile(profile.get());
@@ -1841,12 +1847,12 @@ void KdenliveDoc::switchProfile(ProfileParam *pf, const QString &clipName)
         connect(ac, &QAction::triggered, this, [this, profilePath]() { this->slotSwitchProfile(profilePath, true); });
         QAction *ac2 = new QAction(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("Cancel"), this);
         QList<QAction *> list = {ac, ac2};
-        adjustMessage.append(i18n("Switch to clip (%1) profile %2?", clipName, profile->descriptiveString()));
-        pCore->displayBinMessage(adjustMessage, KMessageWidget::Information, list, false, BinMessage::BinCategory::ProfileMessage);
+        pCore->displayBinMessage(i18n("Switch to clip (%1) profile %2?", clipName, profile->descriptiveString()), KMessageWidget::Information, list, false,
+                                 BinMessage::BinCategory::ProfileMessage);
     } else {
         // No known profile, ask user if he wants to use clip profile anyway
         if (qFuzzyCompare(double(profile->m_frame_rate_num) / profile->m_frame_rate_den, fps)) {
-            adjustMessage.append(i18n("\nProfile fps adjusted from original %1", QString::number(fps, 'f', 4)));
+            adjustMessage = i18n("\nProfile fps adjusted from original %1", QString::number(fps, 'f', 4));
         }
         if (KMessageBox::warningContinueCancel(pCore->window(), i18n("No profile found for your clip %1.\nCreate and switch to new profile (%2x%3, %4fps)?%5",
                                                                      clipName, profile->m_width, profile->m_height,
@@ -2085,15 +2091,12 @@ QStringList KdenliveDoc::getProxyHashList()
     return pCore->bin()->getProxyHashList();
 }
 
-std::shared_ptr<TimelineItemModel> KdenliveDoc::getTimeline(const QUuid &uuid, bool allowEmpty)
+std::shared_ptr<TimelineItemModel> KdenliveDoc::getTimeline(const QUuid &uuid)
 {
     if (m_timelines.contains(uuid)) {
         return m_timelines.value(uuid);
     }
-    if (!allowEmpty) {
-        qDebug() << "REQUESTING UNKNOWN TIMELINE: " << uuid;
-        Q_ASSERT(false);
-    }
+    qDebug() << "REQUESTING UNKNOWN TIMELINE: " << uuid;
     return nullptr;
 }
 
@@ -2102,29 +2105,14 @@ QList<QUuid> KdenliveDoc::getTimelinesUuids() const
     return m_timelines.keys();
 }
 
-QStringList KdenliveDoc::getTimelinesIds()
-{
-    QStringList ids;
-    QMapIterator<QUuid, std::shared_ptr<TimelineItemModel>> j(m_timelines);
-    while (j.hasNext()) {
-        j.next();
-        ids << QString(j.value()->tractor()->get("id"));
-    }
-    return ids;
-}
-
 void KdenliveDoc::addTimeline(const QUuid &uuid, std::shared_ptr<TimelineItemModel> model, bool force)
 {
     if (force && m_timelines.find(uuid) != m_timelines.end()) {
-        std::shared_ptr<TimelineItemModel> previousModel = m_timelines.take(uuid);
-        previousModel.reset();
+        std::shared_ptr<TimelineItemModel> model = m_timelines.take(uuid);
+        model.reset();
     }
     if (m_timelines.find(uuid) != m_timelines.end()) {
         qDebug() << "::::: TIMELINE " << uuid << " already inserted in project";
-        if (m_timelines.value(uuid) != model) {
-            qDebug() << "::::: TIMELINE INCONSISTENCY";
-            Q_ASSERT(false);
-        }
         return;
     }
     if (m_timelines.isEmpty()) {
@@ -2166,22 +2154,17 @@ void KdenliveDoc::loadSequenceGroupsAndGuides(const QUuid &uuid)
     connect(model.get(), &TimelineModel::saveGuideCategories, this, &KdenliveDoc::saveGuideCategories);
 }
 
-void KdenliveDoc::closeTimeline(const QUuid uuid, bool onDeletion)
+void KdenliveDoc::closeTimeline(const QUuid uuid)
 {
     Q_ASSERT(m_timelines.find(uuid) != m_timelines.end());
     // Sync all sequence properties
-    if (onDeletion) {
-        auto model = m_timelines.take(uuid);
-        model->prepareClose(!closing);
-        model.reset();
-    } else {
-        auto model = m_timelines.value(uuid);
-        if (!closing) {
-            setSequenceProperty(uuid, QStringLiteral("groups"), model->groupsData());
-            model->passSequenceProperties(getSequenceProperties(uuid));
-        }
-        model->isClosed = true;
+    std::shared_ptr<TimelineItemModel> model = m_timelines.take(uuid);
+    if (!closing) {
+        setSequenceProperty(uuid, QStringLiteral("groups"), model->groupsData());
+        model->passSequenceProperties(getSequenceProperties(uuid));
     }
+    model->prepareClose(!closing);
+    model.reset();
     // Clear all sequence properties
     m_sequenceProperties.remove(uuid);
 }
@@ -2319,6 +2302,7 @@ void KdenliveDoc::generateRenderSubtitleFile(const QUuid &uuid, int in, int out,
     }
 }
 
+// static
 void KdenliveDoc::useOriginals(QDomDocument &doc)
 {
     QString root = doc.documentElement().attribute(QStringLiteral("root"));
@@ -2334,6 +2318,7 @@ void KdenliveDoc::useOriginals(QDomDocument &doc)
     processProxyNodes(chains, root, proxies);
 }
 
+// static
 void KdenliveDoc::disableSubtitles(QDomDocument &doc)
 {
     QDomNodeList filters = doc.elementsByTagName(QStringLiteral("filter"));
@@ -2348,11 +2333,11 @@ void KdenliveDoc::disableSubtitles(QDomDocument &doc)
 void KdenliveDoc::makeBackgroundTrackTransparent(QDomDocument &doc)
 {
     QDomNodeList prods = doc.elementsByTagName(QStringLiteral("producer"));
-    // Switch all black track producers to transparent
     for (int i = 0; i < prods.length(); ++i) {
         auto prod = prods.at(i).toElement();
         if (Xml::getXmlProperty(prod, QStringLiteral("kdenlive:playlistid")) == QStringLiteral("black_track")) {
             Xml::setXmlProperty(prod, QStringLiteral("resource"), QStringLiteral("0"));
+            break;
         }
     }
 }
