@@ -85,6 +85,7 @@ private:
 class KdenliveDoc : public QObject
 {
     Q_OBJECT
+
 public:
     friend class LoadJob;
     friend class TimelineModel;
@@ -266,6 +267,7 @@ public:
     QDomDocument createEmptyDocument(int videotracks, int audiotracks, bool disableProfile = true);
     /** @brief Return the document version. */
     double getDocumentVersion() const;
+
     /** @brief Returns true if this project has subtitles. */
     bool hasSubtitles() const;
     /** @brief Generate a temporary subtitle file for a zone. */
@@ -276,16 +278,13 @@ public:
     /** @brief Load the guides into the model for a sequence.*/
     void loadSequenceGroupsAndGuides(const QUuid &uuid);
     /** @brief Get a timeline by its uuid.*/
-    std::shared_ptr<TimelineItemModel> getTimeline(const QUuid &uuid, bool allowEmpty = false);
+    std::shared_ptr<TimelineItemModel> getTimeline(const QUuid &uuid);
     /** @brief Before closing a timeline, store its groups and other properties.*/
-    void closeTimeline(const QUuid uuid, bool onDeletion = true);
+    void closeTimeline(const QUuid uuid);
     /** @brief store groups in our properties.*/
     void storeGroups(const QUuid &uuid);
     void checkUsage(const QUuid &uuid);
-    /** @brief Return all timelines UUIDs.*/
     QList<QUuid> getTimelinesUuids() const;
-    /** @brief Return all timelines MLT ids.*/
-    QStringList getTimelinesIds();
     /** @brief Returns the number of timelines in this project.*/
     int openedTimelineCount() const;
     /** @brief Get the currently active project name.*/
@@ -294,7 +293,6 @@ public:
     const QUuid uuid() const;
     /** @brief Returns true if a sequence thumbnail needs an update.*/
     bool sequenceThumbRequiresRefresh(const QUuid &uuid) const;
-    void setSequenceThumbRequiresUpdate(const QUuid &uuid);
     /** @brief Thumbnail for a sequence was updated, remove it from the update list.*/
     void sequenceThumbUpdated(const QUuid &uuid);
 
