@@ -20,12 +20,14 @@
 #include <QDebug>
 #include <QMenu>
 #include <QMessageBox>
+#include <QMimeData>
 
 EffectTreeModel::EffectTreeModel(QObject *parent)
     : AssetTreeModel(parent)
     , m_customCategory(nullptr)
     , m_templateCategory(nullptr)
 {
+    m_assetIconProvider = new AssetIconProvider(true, this);
 }
 
 std::shared_ptr<EffectTreeModel> EffectTreeModel::construct(const QString &categoryFile, QObject *parent)
@@ -82,7 +84,8 @@ std::shared_ptr<EffectTreeModel> EffectTreeModel::construct(const QString &categ
 
         if (type == AssetListType::AssetType::Custom || type == AssetListType::AssetType::CustomAudio) {
             targetCategory = self->m_customCategory;
-        } else if (type == AssetListType::AssetType::Template || type == AssetListType::AssetType::TemplateAudio) {
+        }
+        if (type == AssetListType::AssetType::Template || type == AssetListType::AssetType::TemplateAudio) {
             targetCategory = self->m_templateCategory;
         }
 
@@ -118,28 +121,21 @@ void EffectTreeModel::reloadEffectFromIndex(const QModelIndex &index)
 void EffectTreeModel::reloadEffect(const QString &path)
 {
     QPair<QString, QString> asset = EffectsRepository::get()->reloadCustom(path);
-    AssetListType::AssetType type = EffectsRepository::get()->getType(asset.first);
-    std::shared_ptr<TreeItem> targetCategory = nullptr;
-    if (type == AssetListType::AssetType::Custom || type == AssetListType::AssetType::CustomAudio) {
-        targetCategory = m_customCategory;
-    } else if (type == AssetListType::AssetType::Template || type == AssetListType::AssetType::TemplateAudio) {
-        targetCategory = m_templateCategory;
-    }
-    if (asset.first.isEmpty() || targetCategory == nullptr) {
+    if (asset.first.isEmpty() || m_customCategory == nullptr) {
         return;
     }
     // Check if item already existed, and remove
-    for (int i = 0; i < targetCategory->childCount(); i++) {
-        std::shared_ptr<TreeItem> item = targetCategory->child(i);
+    for (int i = 0; i < m_customCategory->childCount(); i++) {
+        std::shared_ptr<TreeItem> item = m_customCategory->child(i);
         if (item->dataColumn(IdCol).toString() == asset.first) {
-            targetCategory->removeChild(item);
+            m_customCategory->removeChild(item);
             break;
         }
     }
     bool isFav = KdenliveSettings::favorite_effects().contains(asset.first);
     QString effectName = EffectsRepository::get()->getName(asset.first);
-    QList<QVariant> data{effectName, asset.first, QVariant::fromValue(type), isFav};
-    targetCategory->appendChild(data);
+    QList<QVariant> data{effectName, asset.first, QVariant::fromValue(AssetListType::AssetType::Custom), isFav};
+    m_customCategory->appendChild(data);
 }
 
 void EffectTreeModel::deleteEffect(const QModelIndex &index)
@@ -153,31 +149,6 @@ void EffectTreeModel::deleteEffect(const QModelIndex &index)
     EffectsRepository::get()->deleteEffect(id);
 }
 
-void EffectTreeModel::reloadTemplates()
-{
-    // First remove all templates effects
-    if (!m_templateCategory) {
-        return;
-    }
-    // Check if item already existed, and remove
-    while (m_templateCategory->childCount() > 0) {
-        std::shared_ptr<TreeItem> item = m_templateCategory->child(0);
-        m_templateCategory->removeChild(item);
-    }
-    QStringList asset_dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("effect-templates"), QStandardPaths::LocateDirectory);
-    QListIterator<QString> dirs_it(asset_dirs);
-    for (dirs_it.toBack(); dirs_it.hasPrevious();) {
-        auto dir = dirs_it.previous();
-        QDir current_dir(dir);
-        QStringList filter{QStringLiteral("*.xml")};
-        QStringList fileList = current_dir.entryList(filter, QDir::Files);
-        for (const auto &file : qAsConst(fileList)) {
-            QString path = current_dir.absoluteFilePath(file);
-            reloadEffect(path);
-        }
-    }
-}
-
 void EffectTreeModel::reloadAssetMenu(QMenu *effectsMenu, KActionCategory *effectActions)
 {
     for (int i = 0; i < rowCount(); i++) {
@@ -300,3 +271,18 @@ void EffectTreeModel::editCustomAsset(const QString &newName, const QString &new
         reloadEffect(oldpath);
     }
 }
+
+QMimeData *EffectTreeModel::mimeData(const QModelIndexList &indexes) const
+{
+    QMimeData *mimeData = new QMimeData;
+    std::shared_ptr<TreeItem> item = getItemById(int(indexes.first().internalId()));
+    if (item) {
+        const QString assetId = item->dataColumn(AssetTreeModel::IdCol).toString();
+        mimeData->setData(QStringLiteral("kdenlive/effect"), assetId.toUtf8());
+        if (EffectsRepository::get()->isAudioEffect(assetId)) {
+            qDebug() << "::::: ASSET IS AUDIO!!!";
+            mimeData->setData(QStringLiteral("type"), QByteArray("audio"));
+        }
+    }
+    return mimeData;
+}
