@@ -31,12 +31,11 @@ public:
     QString getMimeType(const QString &assetId) const override;
     void reloadEffectMenu(QMenu *effectsMenu, KActionCategory *effectActions);
     void reloadCustomEffectIx(const QModelIndex &index) override;
-    void reloadTemplates() override;
     void editCustomAsset(const QModelIndex &index) override;
-    Q_INVOKABLE void exportCustomEffect(const QModelIndex &index);
+    void exportCustomEffect(const QModelIndex &index) override;
 
 public Q_SLOTS:
-    void reloadCustomEffect(const QString &path) override;
+    void reloadCustomEffect(const QString &path);
 
 Q_SIGNALS:
     void reloadFavorites();
