@@ -85,7 +85,7 @@ void EffectStackModel::removeService(const std::shared_ptr<Mlt::Service> &servic
 void EffectStackModel::removeCurrentEffect()
 {
     int ix = getActiveEffect();
-    if (ix < 0 || ix >= rootItem->childCount()) {
+    if (ix < 0) {
         return;
     }
     std::shared_ptr<EffectItemModel> effect = std::static_pointer_cast<EffectItemModel>(rootItem->child(ix));
@@ -485,7 +485,7 @@ bool EffectStackModel::copyEffect(const std::shared_ptr<AbstractEffectItem> &sou
     return res;
 }
 
-bool EffectStackModel::appendEffect(const QString &effectId, bool makeCurrent)
+bool EffectStackModel::appendEffect(const QString &effectId, bool makeCurrent, stringMap params)
 {
     QWriteLocker locker(&m_lock);
     if (m_ownerId.type == ObjectType::TimelineClip && EffectsRepository::get()->isUnique(effectId) && hasEffect(effectId)) {
@@ -513,6 +513,11 @@ bool EffectStackModel::appendEffect(const QString &effectId, bool makeCurrent)
             return false;
         }
     }
+    QMapIterator<QString, QString> i(params);
+    while (i.hasNext()) {
+        i.next();
+        effect->filter().set(i.key().toUtf8().constData(), i.value().toUtf8().constData());
+    }
     Fun undo = removeItem_lambda(effect->getId());
     // TODO the parent should probably not always be the root
     Fun redo = addItem_lambda(effect, rootItem->getId());
