@@ -616,7 +616,7 @@ Q_SIGNALS:
     void setRenderProgress(int);
     void displayMessage(const QString &, MessageType, int);
     void displaySelectionMessage(const QString &);
-    void displayProgressMessage(const QString &, MessageType, int);
+    void displayProgressMessage(const QString &, MessageType, int, bool canBeStopped = false);
     /** @brief Project profile changed, update render widget accordingly. */
     void updateRenderWidgetProfile();
     /** @brief Clear asset view if itemId is displayed. */
