@@ -465,10 +465,7 @@ void ClipController::updateProducer(const std::shared_ptr<Mlt::Producer> &produc
         // Pass properties from previous producer
         m_properties->pass_list(passProperties, passList);
         setProducerProperty(QStringLiteral("kdenlive:id"), m_controllerBinId);
-        if (m_clipType != ClipType::Timeline) {
-            // Timeline clips effect stack point to the tractor and are handled in ProjectClip::reloadTimeline
-            m_effectStack->resetService(m_masterProducer);
-        }
+        m_effectStack->resetService(m_masterProducer);
         if (m_clipType == ClipType::Unknown) {
             getInfoForProducer();
         }
@@ -1027,9 +1024,9 @@ std::shared_ptr<EffectStackModel> ClipController::getEffectStack() const
     return m_effectStack;
 }
 
-bool ClipController::addEffect(const QString &effectId)
+bool ClipController::addEffect(const QString &effectId, stringMap params)
 {
-    return m_effectStack->appendEffect(effectId, true);
+    return m_effectStack->appendEffect(effectId, true, params);
 }
 
 bool ClipController::copyEffect(const std::shared_ptr<EffectStackModel> &stackModel, int rowId)
@@ -1110,7 +1107,7 @@ const QString ClipController::getOriginalUrl()
     if (path.isEmpty()) {
         path = m_path;
     }
-    if (!path.isEmpty() && QFileInfo(path).isRelative()) {
+    if (QFileInfo(path).isRelative()) {
         path.prepend(pCore->currentDoc()->documentRoot());
     }
     return path;
