@@ -468,7 +468,7 @@ void ArchiveWidget::generateItems(QTreeWidgetItem *parentItem, const QStringList
             }
         } else if (filesList.contains(fileName) && !filesPath.contains(file)) {
             // we have 2 different files with same name
-            QString fileName = QStringUtils::getUniqueFileName(filesList, fileName);
+            QString fileName = QStringUtils::getUniqueName(filesList, fileName);
             item->setData(0, Qt::UserRole, fileName);
         }
         if (!isSlideshow) {
@@ -553,8 +553,7 @@ void ArchiveWidget::generateItems(QTreeWidgetItem *parentItem, const QMap<QStrin
             }
         } else if (filesList.contains(fileName) && !filesPath.contains(file)) {
             // we have 2 different files with same name
-            const QString previousName = fileName;
-            fileName = QStringUtils::getUniqueFileName(filesList, previousName);
+            QString fileName = QStringUtils::getUniqueName(filesList, fileName);
             item->setData(0, Qt::UserRole, fileName);
         }
         if (!isSlideshow) {
@@ -622,7 +621,7 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
         repaint();
     }
     QList<QUrl> files;
-    QDir destUrl;
+    QUrl destUrl;
     QString destPath;
     QTreeWidgetItem *parentItem;
     bool isSlideshow = false;
@@ -659,7 +658,7 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
         files_list->setCurrentItem(parentItem);
         parentItem->setExpanded(true);
         destPath = parentItem->data(0, Qt::UserRole).toString() + QLatin1Char('/');
-        destUrl = QDir(archive_url->url().toLocalFile() + QLatin1Char('/') + destPath);
+        destUrl = QUrl::fromLocalFile(archive_url->url().toLocalFile() + QLatin1Char('/') + destPath);
         QTreeWidgetItem *item;
         for (int j = 0; j < parentItem->childCount(); ++j) {
             item = parentItem->child(j);
@@ -681,10 +680,11 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
                     m_temp->close();
                     m_filesList.insert(m_temp->fileName(), destPath + filename);
                 } else {
-                    if (!destUrl.mkpath(QStringLiteral("."))) {
-                        KMessageBox::error(this, i18n("Cannot create directory %1", destUrl.absolutePath()));
+                    QDir dir(destUrl.toLocalFile());
+                    if (!dir.mkpath(QStringLiteral("."))) {
+                        KMessageBox::error(this, i18n("Cannot create directory %1", destUrl.toLocalFile()));
                     }
-                    QFile file(destUrl.absoluteFilePath(filename));
+                    QFile file(dir.absoluteFilePath(filename));
                     if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
                         qCWarning(KDENLIVE_LOG) << "//////  ERROR writing to file: " << file.fileName();
                         KMessageBox::error(this, i18n("Cannot write to file %1", file.fileName()));
@@ -700,7 +700,7 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
             } else if (isSlideshow) {
                 // Special case: slideshows
                 destPath += item->data(0, Qt::UserRole).toString() + QLatin1Char('/');
-                destUrl = QDir(archive_url->url().toLocalFile() + QDir::separator() + destPath);
+                destUrl = QUrl::fromLocalFile(archive_url->url().toLocalFile() + QDir::separator() + destPath);
                 QStringList srcFiles = item->data(0, SlideshowImagesRole).toStringList();
                 for (int k = 0; k < srcFiles.count(); ++k) {
                     files << QUrl::fromLocalFile(srcFiles.at(k));
@@ -721,7 +721,7 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
                     m_filesList.insert(item->text(0), destPath + item->data(0, Qt::UserRole).toString());
                 } else {
                     m_duplicateFiles.insert(QUrl::fromLocalFile(item->text(0)),
-                                            QUrl::fromLocalFile(destUrl.absoluteFilePath(item->data(0, Qt::UserRole).toString())));
+                                            QUrl::fromLocalFile(destUrl.toLocalFile() + QLatin1Char('/') + item->data(0, Qt::UserRole).toString()));
                 }
             }
         }
@@ -733,7 +733,7 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
         break;
     }
 
-    if (items == 0 && isLastCategory && m_duplicateFiles.isEmpty()) {
+    if (items == 0 && isLastCategory) {
         // No clips to archive
         slotArchivingFinished(nullptr, true);
         return true;
@@ -746,8 +746,8 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
         QMapIterator<QUrl, QUrl> i(m_duplicateFiles);
         if (i.hasNext()) {
             i.next();
-            const QUrl startJobSrc = i.key();
-            const QUrl startJobDst = i.value();
+            QUrl startJobSrc = i.key();
+            QUrl startJobDst = i.value();
             m_duplicateFiles.remove(startJobSrc);
             m_infoMessage->setText(i18n("Copying %1", startJobSrc.fileName()));
             KIO::CopyJob *job = KIO::copyAs(startJobSrc, startJobDst, KIO::HideProgressInfo);
@@ -766,10 +766,11 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
     } else if (files.isEmpty()) {
         slotStartArchiving(false);
     } else {
-        if (!destUrl.mkpath(QStringLiteral("."))) {
-            KMessageBox::error(this, i18n("Cannot create directory %1", destUrl.absolutePath()));
+        QDir dir(destUrl.toLocalFile());
+        if (!dir.mkpath(QStringLiteral("."))) {
+            KMessageBox::error(this, i18n("Cannot create directory %1", destUrl.toLocalFile()));
         }
-        m_copyJob = KIO::copy(files, QUrl::fromLocalFile(destUrl.absolutePath()), KIO::HideProgressInfo);
+        m_copyJob = KIO::copy(files, destUrl, KIO::HideProgressInfo);
         connect(m_copyJob, &KJob::result, this, [this](KJob *jb) { slotArchivingFinished(jb, false); });
         connect(m_copyJob, &KJob::processedSize, this, &ArchiveWidget::slotArchivingProgress);
     }
@@ -1115,6 +1116,9 @@ void ArchiveWidget::createArchive()
             Q_EMIT archiveProgress(100 * ix / max);
             ix++;
             if (!success || m_abortArchive) {
+                if (!success) {
+                    errorString.append(i18n("Cannot copy file %1 to %2.", i.key(), i.value()));
+                }
                 break;
             }
         }
@@ -1134,9 +1138,7 @@ void ArchiveWidget::createArchive()
         m_temp = nullptr;
     }
 
-    if (errorString.isEmpty()) {
-        errorString = m_archive->errorString();
-    }
+    errorString.append(m_archive->errorString());
     success = success && m_archive->close();
 
     Q_EMIT archivingFinished(success, errorString);
