@@ -43,6 +43,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KNotification>
 #include <KRecentDirs>
 #include <kcoreaddons_version.h>
 
@@ -59,6 +60,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QProgressDialog>
 #include <QSaveFile>
 #include <QTimeZone>
+#include <QUndoGroup>
 
 static QString getProjectNameFilters(bool ark = true)
 {
@@ -121,6 +123,18 @@ void ProjectManager::slotLoadOnOpen()
     pCore->window()->checkMaxCacheSize();
 }
 
+void ProjectManager::slotLoadHeadless(const QUrl &projectUrl)
+{
+    m_loading = true;
+    if (projectUrl.isValid()) {
+        doOpenFileHeadless(projectUrl);
+    }
+    m_loading = false;
+    // Release startup crash lock file
+    QFile lockFile(QDir::temp().absoluteFilePath(QStringLiteral("kdenlivelock")));
+    lockFile.remove();
+}
+
 void ProjectManager::init(const QUrl &projectUrl, const QString &clipList)
 {
     m_startUrl = projectUrl;
@@ -263,11 +277,8 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
         }
     }
     activateDocument(m_project->activeUuid);
-    std::shared_ptr<ProjectClip> mainClip = pCore->projectItemModel()->getSequenceClip(m_project->uuid());
-    if (mainClip) {
-        mainClip->reloadTimeline(m_activeTimelineModel->getMasterEffectStackModel());
-    }
     Q_EMIT docOpened(m_project);
+    Q_EMIT pCore->gotMissingClipsCount(0, 0);
     m_project->loading = false;
     m_lastSave.start();
     if (pCore->monitorManager()) {
@@ -329,39 +340,15 @@ void ProjectManager::testSetActiveDocument(KdenliveDoc *doc, std::shared_ptr<Tim
             qDebug() << "===== LOADING PROJECT INTERNAL ERROR";
         }
     }
-    const QUuid uuid = timeline->uuid();
-    m_project->addTimeline(uuid, timeline);
-    timeline->isClosed = false;
+    m_project->addTimeline(doc->uuid(), timeline);
     m_activeTimelineModel = timeline;
-    m_project->activeUuid = uuid;
-    m_project->loadSequenceGroupsAndGuides(uuid);
-    // Open all other timelines
-    QMap<QUuid, QString> allSequences = pCore->projectItemModel()->getAllSequenceClips();
-    QMapIterator<QUuid, QString> i(allSequences);
-    while (i.hasNext()) {
-        i.next();
-        if (m_project->getTimeline(i.key(), true) == nullptr) {
-            const QUuid uid = i.key();
-            std::shared_ptr<Mlt::Tractor> tc = pCore->projectItemModel()->getExtraTimeline(uid.toString());
-            if (tc) {
-                std::shared_ptr<TimelineItemModel> timelineModel = TimelineItemModel::construct(uid, m_project->commandStack());
-                const QString chunks = m_project->getSequenceProperty(uid, QStringLiteral("previewchunks"));
-                const QString dirty = m_project->getSequenceProperty(uid, QStringLiteral("dirtypreviewchunks"));
-                if (constructTimelineFromTractor(timelineModel, nullptr, *tc.get(), nullptr, m_project->modifiedDecimalPoint(), chunks, dirty)) {
-                    m_project->addTimeline(uid, timelineModel, false);
-                    pCore->projectItemModel()->setExtraTimelineSaved(uid.toString());
-                    std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(timelineModel->tractor());
-                    passSequenceProperties(uid, prod, *tc.get(), timelineModel, nullptr);
-                    std::shared_ptr<ProjectClip> clip = pCore->projectItemModel()->getClipByBinID(i.value());
-                    prod->parent().set("kdenlive:clipname", clip->clipName().toUtf8().constData());
-                    prod->set("kdenlive:description", clip->description().toUtf8().constData());
-                    // Store sequence properties for later re-use
-                    m_project->loadSequenceGroupsAndGuides(uid);
-                    clip->setProducer(prod, false, false);
-                    clip->reloadTimeline(timelineModel->getMasterEffectStackModel());
-                }
-            }
+    m_project->activeUuid = doc->uuid();
+    std::shared_ptr<ProjectClip> mainClip = pCore->projectItemModel()->getClipByBinID(pCore->projectItemModel()->getSequenceId(doc->uuid()));
+    if (mainClip) {
+        if (timeline->getGuideModel() == nullptr) {
+            timeline->setMarkerModel(mainClip->markerModel());
         }
+        m_project->loadSequenceGroupsAndGuides(doc->uuid());
     }
 }
 
@@ -421,6 +408,10 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
             break;
         }
     }
+
+    // Abort clip loading if any
+    Q_EMIT pCore->stopProgressTask();
+    qApp->processEvents();
     bool guiConstructed = pCore->window() != nullptr;
     if (guiConstructed) {
         pCore->window()->disableMulticam();
@@ -430,11 +421,11 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
         pCore->monitorManager()->projectMonitor()->setProducer(nullptr);
     }
     if (m_project) {
+        pCore->taskManager.slotCancelJobs(true);
         m_project->closing = true;
         if (guiConstructed && !quit && !qApp->isSavingSession()) {
             pCore->bin()->abortOperations();
         }
-        pCore->taskManager.slotCancelJobs(true);
         m_project->commandStack()->clear();
         pCore->cleanup();
         if (guiConstructed) {
@@ -442,13 +433,13 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
             for (auto &uid : uuids) {
                 pCore->window()->closeTimelineTab(uid);
                 pCore->window()->resetSubtitles(uid);
-                m_project->closeTimeline(uid, true);
+                m_project->closeTimeline(uid);
             }
         } else {
             // Close all timelines
             const QList<QUuid> uuids = m_project->getTimelinesUuids();
             for (auto &uid : uuids) {
-                m_project->closeTimeline(uid, true);
+                m_project->closeTimeline(uid);
             }
         }
     }
@@ -485,7 +476,6 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveOverExis
     prepareSave();
     QString saveFolder = QFileInfo(outputFileName).absolutePath();
     m_project->updateWorkFilesBeforeSave(outputFileName);
-    checkProjectIntegrity();
     QString scene = projectSceneList(saveFolder);
     if (!m_replacementPattern.isEmpty()) {
         QMapIterator<QString, QString> i(m_replacementPattern);
@@ -496,6 +486,7 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveOverExis
     }
     m_project->updateWorkFilesAfterSave();
     if (!m_project->saveSceneList(outputFileName, scene, saveOverExistingFile)) {
+        KNotification::event(QStringLiteral("ErrorMessage"), i18n("Saving project file <br><b>%1</B> failed", outputFileName), QPixmap());
         return false;
     }
     QUrl url = QUrl::fromLocalFile(outputFileName);
@@ -528,6 +519,7 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveOverExis
         pCore->window()->setWindowTitle(m_project->description());
         m_project->setModified(false);
     }
+    KNotification::event(QStringLiteral("SaveSuccess"), i18n("Saving successful"), QPixmap());
 
     m_recentFilesAction->addUrl(url);
     // remember folder for next project opening
@@ -743,6 +735,17 @@ void ProjectManager::openFile(const QUrl &url)
     doOpenFile(url, nullptr);
 }
 
+void ProjectManager::abortLoading()
+{
+    KMessageBox::error(pCore->window(), i18n("Could not recover corrupted file."));
+    delete m_progressDialog;
+    m_progressDialog = nullptr;
+    // Don't propose to save corrupted doc
+    m_project->setModified(false);
+    // Open default blank document
+    newFile(false);
+}
+
 void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBackup)
 {
     Q_ASSERT(m_project == nullptr);
@@ -845,7 +848,6 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBa
     m_project = doc;
     pCore->monitorManager()->projectMonitor()->locked = true;
     QDateTime documentDate = QFileInfo(m_project->url().toLocalFile()).lastModified();
-
     if (!updateTimeline(true, m_project->getDocumentProperty(QStringLiteral("previewchunks")),
                         m_project->getDocumentProperty(QStringLiteral("dirtypreviewchunks")), documentDate,
                         m_project->getDocumentProperty(QStringLiteral("disablepreview")).toInt())) {
@@ -862,46 +864,15 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBa
 
     // Re-open active timelines
     QStringList openedTimelines = m_project->getDocumentProperty(QStringLiteral("opensequences")).split(QLatin1Char(';'), Qt::SkipEmptyParts);
-    QList<QUuid> openedUuids;
     for (auto &uid : openedTimelines) {
         const QUuid uuid(uid);
-        openedUuids << uuid;
         const QString binId = pCore->projectItemModel()->getSequenceId(uuid);
         if (!binId.isEmpty()) {
             openTimeline(binId, uuid);
         }
     }
     // Now that sequence clips are fully built, fetch thumbnails
-    auto sequences = pCore->projectItemModel()->getAllSequenceClips();
-    QList<QUuid> uuids = sequences.keys();
-    // Load all sequence models into memory
-    for (auto &uid : uuids) {
-        if (pCore->currentDoc()->getTimeline(uid, true) == nullptr) {
-            std::shared_ptr<Mlt::Tractor> tc = pCore->projectItemModel()->getExtraTimeline(uid.toString());
-            if (tc) {
-                std::shared_ptr<TimelineItemModel> timelineModel = TimelineItemModel::construct(uid, m_project->commandStack());
-                const QString chunks = m_project->getSequenceProperty(uid, QStringLiteral("previewchunks"));
-                const QString dirty = m_project->getSequenceProperty(uid, QStringLiteral("dirtypreviewchunks"));
-                const QString binId = pCore->projectItemModel()->getSequenceId(uid);
-                m_project->addTimeline(uid, timelineModel, false);
-                if (constructTimelineFromTractor(timelineModel, nullptr, *tc.get(), nullptr, m_project->modifiedDecimalPoint(), chunks, dirty)) {
-                    pCore->projectItemModel()->setExtraTimelineSaved(uid.toString());
-                    std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(timelineModel->tractor());
-                    passSequenceProperties(uid, prod, *tc.get(), timelineModel, nullptr);
-                    std::shared_ptr<ProjectClip> clip = pCore->projectItemModel()->getClipByBinID(binId);
-                    prod->parent().set("kdenlive:clipname", clip->clipName().toUtf8().constData());
-                    prod->set("kdenlive:description", clip->description().toUtf8().constData());
-                    m_project->loadSequenceGroupsAndGuides(uid);
-                    clip->setProducer(prod, false, false);
-                    clip->reloadTimeline(timelineModel->getMasterEffectStackModel());
-                } else {
-                    qWarning() << "XXXXXXXXX\nLOADING TIMELINE " << uid.toString() << " FAILED\n";
-                    m_project->closeTimeline(uid, true);
-                }
-            }
-        }
-    }
-    const QStringList sequenceIds = sequences.values();
+    const QStringList sequenceIds = pCore->projectItemModel()->getAllSequenceClips().values();
     for (auto &id : sequenceIds) {
         ClipLoadTask::start(ObjectId(ObjectType::BinClip, id.toInt(), QUuid()), QDomElement(), true, -1, -1, this);
     }
@@ -915,20 +886,11 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBa
         if (binId.isEmpty()) {
             if (pCore->projectItemModel()->sequenceCount() == 0) {
                 // Something is broken here, abort
-                KMessageBox::error(pCore->window(), i18n("Could not recover corrupted file."));
-                delete m_progressDialog;
-                m_progressDialog = nullptr;
-                // Don't propose to save broken document
-                m_project->setModified(false);
-                // Open default blank document
-                newFile(false);
+                abortLoading();
                 return;
             }
-        }
-        if (!binId.isEmpty()) {
-            openTimeline(binId, activeUuid);
         } else {
-            qDebug() << ":::::::::\n\nNO BINID FOR TIMELINE: " << activeUuid << "\n\n:::::::::::::";
+            openTimeline(binId, activeUuid);
         }
     }
     pCore->window()->connectDocument();
@@ -948,12 +910,58 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBa
         const QUuid uuid = m_project->activeUuid;
         pCore->monitorManager()->projectMonitor()->adjustRulerSize(m_activeTimelineModel->duration() - 1, m_project->getFilteredGuideModel(uuid));
     }
-
-    checkProjectWarnings();
+    pCore->projectItemModel()->missingClipTimer.start();
     delete m_progressDialog;
     m_progressDialog = nullptr;
 }
 
+void ProjectManager::doOpenFileHeadless(const QUrl &url)
+{
+    Q_ASSERT(m_project == nullptr);
+    QUndoGroup *undoGroup = new QUndoGroup();
+    std::shared_ptr<DocUndoStack> undoStack = std::make_shared<DocUndoStack>(nullptr);
+    undoGroup->addStack(undoStack.get());
+
+    DocOpenResult openResult = KdenliveDoc::Open(url, QString() /*QDir::temp().path()*/, undoGroup, false, nullptr);
+
+    KdenliveDoc *doc = nullptr;
+    if (!openResult.isSuccessful() && !openResult.isAborted()) {
+        qCritical() << i18n("Cannot open the project file. Error:\n%1\n", openResult.getError());
+    } else {
+        doc = openResult.getDocument().release();
+    }
+
+    // if we could not open the file, and could not recover (or user declined), stop now
+    if (!openResult.isSuccessful() || !doc) {
+        return;
+    }
+
+    // Set default target tracks to upper audio / lower video tracks
+    m_project = doc;
+
+    if (!updateTimeline(false, QString(), QString(), QDateTime(), 0)) {
+        return;
+    }
+
+    // Re-open active timelines
+    QStringList openedTimelines = m_project->getDocumentProperty(QStringLiteral("opensequences")).split(QLatin1Char(';'), Qt::SkipEmptyParts);
+    for (auto &uid : openedTimelines) {
+        const QUuid uuid(uid);
+        const QString binId = pCore->projectItemModel()->getSequenceId(uuid);
+        if (!binId.isEmpty()) {
+            openTimeline(binId, uuid);
+        }
+    }
+    // Raise last active timeline
+    QUuid activeUuid(m_project->getDocumentProperty(QStringLiteral("activetimeline")));
+    if (activeUuid.isNull()) {
+        activeUuid = m_project->uuid();
+    }
+
+    auto timeline = m_project->getTimeline(activeUuid);
+    testSetActiveDocument(m_project, timeline);
+}
+
 void ProjectManager::slotRevert()
 {
     if (m_project->isModified() &&
@@ -1029,10 +1037,6 @@ void ProjectManager::slotStartAutoSave()
 
 void ProjectManager::slotAutoSave()
 {
-    if (m_project->loading) {
-        // Dont start autosave if the project is still loading
-        return;
-    }
     prepareSave();
     QString saveFolder = m_project->url().adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile();
     QString scene = projectSceneList(saveFolder);
@@ -1055,9 +1059,9 @@ void ProjectManager::slotAutoSave()
 QString ProjectManager::projectSceneList(const QString &outputFolder, const QString &overlayData)
 {
     // Disable multitrack view and overlay
-    bool isMultiTrack = pCore->monitorManager()->isMultiTrack();
-    bool hasPreview = pCore->window()->getCurrentTimeline()->controller()->hasPreviewTrack();
-    bool isTrimming = pCore->monitorManager()->isTrimming();
+    bool isMultiTrack = pCore->monitorManager() && pCore->monitorManager()->isMultiTrack();
+    bool hasPreview = pCore->window() && pCore->window()->getCurrentTimeline()->controller()->hasPreviewTrack();
+    bool isTrimming = pCore->monitorManager() && pCore->monitorManager()->isTrimming();
     if (isMultiTrack) {
         pCore->window()->getCurrentTimeline()->controller()->slotMultitrackView(false, false);
     }
@@ -1067,11 +1071,16 @@ QString ProjectManager::projectSceneList(const QString &outputFolder, const QStr
     if (isTrimming) {
         pCore->window()->getCurrentTimeline()->controller()->requestEndTrimmingMode();
     }
-    pCore->mixer()->pauseMonitoring(true);
+    if (pCore->mixer()) {
+        pCore->mixer()->pauseMonitoring(true);
+    }
+
     // We must save from the primary timeline model
     int duration = pCore->window() ? pCore->window()->getCurrentTimeline()->controller()->duration() : m_activeTimelineModel->duration();
     QString scene = pCore->projectItemModel()->sceneList(outputFolder, QString(), overlayData, m_activeTimelineModel->tractor(), duration);
-    pCore->mixer()->pauseMonitoring(false);
+    if (pCore->mixer()) {
+        pCore->mixer()->pauseMonitoring(false);
+    }
     if (isMultiTrack) {
         pCore->window()->getCurrentTimeline()->controller()->slotMultitrackView(true, false);
     }
@@ -1317,14 +1326,10 @@ bool ProjectManager::updateTimeline(bool createNewTab, const QString &chunks, co
     Mlt::Tractor tractor(s);
     if (xmlProd->property_exists("kdenlive:projectTractor")) {
         // This is the new multi-timeline document format
-        // Get active sequence uuid
-        std::shared_ptr<Mlt::Producer> tk(tractor.track(0));
-        const QUuid activeUuid(tk->parent().get("kdenlive:uuid"));
-        Q_ASSERT(!activeUuid.isNull());
         m_project->cleanupTimelinePreview(documentDate);
         pCore->projectItemModel()->buildPlaylist(uuid);
         // Load bin playlist
-        return loadProjectBin(tractor, activeUuid, m_progressDialog);
+        return loadProjectBin(tractor, m_progressDialog);
     }
     if (tractor.count() == 0) {
         // Wow we have a project file with empty tractor, probably corrupted, propose to open a recovery file
@@ -1344,7 +1349,6 @@ bool ProjectManager::updateTimeline(bool createNewTab, const QString &chunks, co
         qDebug() << ":::: NOT FOUND DOCUMENT GUIDES !!!!!!!!!!!\n!!!!!!!!!!!!!!!!!!!!!";
     }
     m_project->addTimeline(uuid, timelineModel);
-    timelineModel->isClosed = false;
     TimelineWidget *documentTimeline = nullptr;
 
     m_project->cleanupTimelinePreview(documentDate);
@@ -1381,26 +1385,8 @@ bool ProjectManager::updateTimeline(bool createNewTab, const QString &chunks, co
         pCore->projectItemModel()->requestAddFolder(folderId, i18n("Sequences"), QStringLiteral("-1"), undo, redo);
     }
     QString mainId;
-    std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(timelineModel->tractor()->cut());
-    passSequenceProperties(uuid, prod, tractor, timelineModel, documentTimeline);
-    pCore->projectItemModel()->requestAddBinClip(mainId, prod, folderId, undo, redo);
-    pCore->projectItemModel()->setSequencesFolder(folderId.toInt());
-    if (pCore->window()) {
-        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration, Qt::UniqueConnection);
-    }
-    std::shared_ptr<ProjectClip> mainClip = pCore->projectItemModel()->getClipByBinID(mainId);
-    m_project->loadSequenceGroupsAndGuides(uuid);
-    timelineModel->setUndoStack(m_project->commandStack());
-
-    // Reset locale to C to ensure numbers are serialised correctly
-    LocaleHandling::resetLocale();
-    return true;
-}
-
-void ProjectManager::passSequenceProperties(const QUuid &uuid, std::shared_ptr<Mlt::Producer> prod, Mlt::Tractor tractor,
-                                            std::shared_ptr<TimelineItemModel> timelineModel, TimelineWidget *timelineWidget)
-{
     QPair<int, int> tracks = timelineModel->getAVtracksCount();
+    std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(timelineModel->tractor()->cut());
     prod->parent().set("id", uuid.toString().toUtf8().constData());
     prod->set("kdenlive:uuid", uuid.toString().toUtf8().constData());
     prod->set("kdenlive:clipname", i18n("Sequence 1").toUtf8().constData());
@@ -1424,18 +1410,34 @@ void ProjectManager::passSequenceProperties(const QUuid &uuid, std::shared_ptr<M
     } else {
         // Fetch duration from actual tractor
         int projectDuration = timelineModel->duration();
-        if (timelineWidget) {
-            timelineWidget->controller()->checkDuration();
+        if (pCore->window()) {
+            documentTimeline->controller()->checkDuration();
         }
         prod->parent().set("kdenlive:duration", timelineModel->tractor()->frames_to_time(projectDuration + 1));
         prod->parent().set("kdenlive:maxduration", projectDuration + 1);
         prod->parent().set("length", projectDuration + 1);
         prod->parent().set("out", projectDuration);
     }
-    if (tractor.property_exists("kdenlive:sequenceproperties.timelineHash")) {
-        prod->parent().set("kdenlive:sequenceproperties.timelineHash", tractor.get("kdenlive:sequenceproperties.timelineHash"));
-    }
     prod->parent().set("kdenlive:producer_type", ClipType::Timeline);
+    // QString retain = QStringLiteral("xml_retain %1").arg(uuid.toString());
+    // pCore->projectItemModel()->projectTractor()->set(retain.toUtf8().constData(), timelineModel->tractor()->get_service(), 0);
+    pCore->projectItemModel()->requestAddBinClip(mainId, prod, folderId, undo, redo);
+    pCore->projectItemModel()->setSequencesFolder(folderId.toInt());
+    if (pCore->window()) {
+        pCore->bin()->registerSequence(uuid, mainId);
+        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration);
+    }
+    std::shared_ptr<ProjectClip> mainClip = pCore->projectItemModel()->getClipByBinID(mainId);
+    timelineModel->setMarkerModel(mainClip->markerModel());
+    m_project->loadSequenceGroupsAndGuides(uuid);
+    if (documentTimeline) {
+        documentTimeline->loadMarkerModel();
+    }
+    timelineModel->setUndoStack(m_project->commandStack());
+
+    // Reset locale to C to ensure numbers are serialised correctly
+    LocaleHandling::resetLocale();
+    return true;
 }
 
 void ProjectManager::updateSequenceDuration(const QUuid &uuid)
@@ -1708,9 +1710,6 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
     if (pCore->window() && pCore->window()->raiseTimeline(uuid)) {
         return false;
     }
-    if (!duplicate && existingModel == nullptr) {
-        existingModel = m_project->getTimeline(uuid, true);
-    }
 
     // Disable autosave while creating timelines
     m_autoSaveTimer.stop();
@@ -1735,9 +1734,11 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
     }
 
     // Build timeline
+    if (existingModel) {
+        existingModel->m_closing = false;
+    }
     std::shared_ptr<TimelineItemModel> timelineModel = existingModel != nullptr ? existingModel : TimelineItemModel::construct(uuid, m_project->commandStack());
     m_project->addTimeline(uuid, timelineModel);
-    timelineModel->isClosed = false;
     TimelineWidget *timeline = nullptr;
     if (internalLoad) {
         qDebug() << "QQQQQQQQQQQQQQQQQQQQ\nINTERNAL SEQUENCE LOAD\n\nQQQQQQQQQQQQQQQQQQQQQQ";
@@ -1774,11 +1775,15 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
         prod->parent().set("kdenlive:description", clip->description().toUtf8().constData());
         prod->parent().set("kdenlive:uuid", uuid.toString().toUtf8().constData());
         prod->parent().set("kdenlive:producer_type", ClipType::Timeline);
-        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration, Qt::UniqueConnection);
+        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration);
+        timelineModel->setMarkerModel(clip->markerModel());
         m_project->loadSequenceGroupsAndGuides(uuid);
         clip->setProducer(prod, false, false);
         if (!duplicate) {
-            clip->reloadTimeline(timelineModel->getMasterEffectStackModel());
+            clip->reloadTimeline();
+        }
+        if (pCore->bin()) {
+            pCore->bin()->registerSequence(uuid, id);
         }
     } else {
         qDebug() << "GOT XML SERV: " << xmlProd->type() << " = " << xmlProd->parent().type();
@@ -1835,7 +1840,9 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
         prod->parent().set("kdenlive:description", clip->description().toUtf8().constData());
         prod->parent().set("kdenlive:uuid", uuid.toString().toUtf8().constData());
         prod->parent().set("kdenlive:producer_type", ClipType::Timeline);
+        timelineModel->setMarkerModel(clip->markerModel());
         if (pCore->bin()) {
+            pCore->bin()->registerSequence(uuid, id);
             pCore->bin()->updateSequenceClip(uuid, timelineModel->duration(), -1);
         }
         updateSequenceProducer(uuid, prod);
@@ -1892,11 +1899,6 @@ int ProjectManager::getTimelinesCount() const
 void ProjectManager::syncTimeline(const QUuid &uuid, bool refresh)
 {
     std::shared_ptr<TimelineItemModel> model = m_project->getTimeline(uuid);
-    doSyncTimeline(model, refresh);
-}
-
-void ProjectManager::doSyncTimeline(std::shared_ptr<TimelineItemModel> model, bool refresh)
-{
     if (model) {
         std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(model->tractor());
         int position = -1;
@@ -1906,7 +1908,6 @@ void ProjectManager::doSyncTimeline(std::shared_ptr<TimelineItemModel> model, bo
                 pCore->window()->getCurrentTimeline()->controller()->saveSequenceProperties();
             }
         }
-        const QUuid &uuid = model->uuid();
         if (refresh) {
             // Store sequence properties for later re-use
             Mlt::Properties sequenceProps;
@@ -1927,13 +1928,11 @@ bool ProjectManager::closeTimeline(const QUuid &uuid, bool onDeletion, bool clea
         qDebug() << "=== ERROR CANNOT FIND TIMELINE TO CLOSE: " << uuid << "\n\nHHHHHHHHHHHH";
         return false;
     }
+    pCore->projectItemModel()->removeReferencedClips(uuid);
     pCore->projectItemModel()->setExtraTimelineSaved(uuid.toString());
     if (onDeletion) {
         // triggered when deleting bin clip, also close timeline tab
-        pCore->projectItemModel()->removeReferencedClips(uuid, true);
-        if (pCore->window()) {
-            pCore->window()->closeTimelineTab(uuid);
-        }
+        pCore->window()->closeTimelineTab(uuid);
     } else {
         if (!m_project->closing && !onDeletion) {
             if (m_project->isModified()) {
@@ -1941,7 +1940,7 @@ bool ProjectManager::closeTimeline(const QUuid &uuid, bool onDeletion, bool clea
             }
         }
     }
-    m_project->closeTimeline(uuid, onDeletion);
+    m_project->closeTimeline(uuid);
     // The undo stack keeps references to guides model and will crash on undo if not cleared
     if (clearUndo) {
         qDebug() << ":::::::::::::: WARNING CLEARING NUDO STACK\n\n:::::::::::::::::";
@@ -2035,9 +2034,15 @@ void ProjectManager::updateSequenceProducer(const QUuid &uuid, std::shared_ptr<M
     pCore->projectItemModel()->storeSequence(uuid.toString(), trac);
 }
 
-void ProjectManager::checkProjectIntegrity()
+void ProjectManager::replaceTimelineInstances(const QString &sourceId, const QString &replacementId, bool replaceAudio, bool replaceVideo)
 {
-    // Ensure the active timeline sequence is correctly inserted in the main_bin playlist
-    const QString activeSequenceId(m_activeTimelineModel->tractor()->get("id"));
-    pCore->projectItemModel()->checkSequenceIntegrity(activeSequenceId);
+    std::shared_ptr<ProjectClip> currentItem = pCore->projectItemModel()->getClipByBinID(sourceId);
+    std::shared_ptr<ProjectClip> replacementItem = pCore->projectItemModel()->getClipByBinID(replacementId);
+    if (!currentItem || !replacementItem || !m_activeTimelineModel) {
+        qDebug() << " SOURCE CLI : " << sourceId << " NOT FOUND!!!";
+        return;
+    }
+    int maxDuration = replacementItem->frameDuration();
+    QList<int> instances = currentItem->timelineInstances();
+    m_activeTimelineModel->processTimelineReplacement(instances, sourceId, replacementId, maxDuration, replaceAudio, replaceVideo);
 }
