@@ -30,7 +30,6 @@ class QAction;
 class QProgressDialog;
 class QUrl;
 class DocUndoStack;
-class TimelineWidget;
 
 /** @class ProjectManager
     @brief Takes care of interaction with projects.
@@ -40,6 +39,7 @@ class /*KDENLIVECORE_EXPORT*/ ProjectManager : public QObject
     Q_OBJECT
 
 public:
+    friend class RenderRequest;
     /** @brief Sets up actions to interact for project interaction (undo, redo, open, save, ...) and creates an empty project. */
     explicit ProjectManager(QObject *parent = nullptr);
     ~ProjectManager() override;
@@ -53,6 +53,7 @@ public:
     void init(const QUrl &projectUrl, const QString &clipList);
 
     void doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBackup = false);
+    void doOpenFileHeadless(const QUrl &url);
     KRecentFilesAction *recentFilesAction();
     void prepareSave();
     /** @brief Disable all bin effects in current project
@@ -125,8 +126,11 @@ public:
     /** @brief Update a timeline sequence before saving or extracting xml
      */
     void syncTimeline(const QUuid &uuid, bool refresh = false);
-    void doSyncTimeline(std::shared_ptr<TimelineItemModel> model, bool refresh);
     void setActiveTimeline(const QUuid &uuid);
+    /** @brief Replace all instance of a @param sourceId clip with another @param replacementId in the active timline sequence
+     * @param replaceAudio if true, only the audio clips will be replaced. if false, only the video parts.
+     */
+    void replaceTimelineInstances(const QString &sourceId, const QString &replacementId, bool replaceAudio, bool replaceVideo);
 
 public Q_SLOTS:
     void newFile(QString profileName, bool showProjectSettings = true);
@@ -137,6 +141,8 @@ public Q_SLOTS:
     /** @brief Load files / clips passed on the command line. */
     void slotLoadOnOpen();
 
+    void slotLoadHeadless(const QUrl &projectUrl);
+
     /** @brief Checks whether a URL is available to save to.
      * @return Whether the file was saved. */
     bool saveFile();
@@ -227,6 +233,7 @@ Q_SIGNALS:
 protected:
     /** @brief Update the timeline according to the MLT XML */
     bool updateTimeline(bool createNewTab, const QString &chunks, const QString &dirty, const QDateTime &documentDate, bool enablePreview);
+    KdenliveDoc *m_project{nullptr};
 
 private:
     /** @brief checks if autoback files exists, recovers from it if user says yes, returns true if files were recovered. */
@@ -234,7 +241,6 @@ private:
     /** @brief Update the sequence producer stored in the project model. */
     void updateSequenceProducer(const QUuid &uuid, std::shared_ptr<Mlt::Producer> prod);
 
-    KdenliveDoc *m_project{nullptr};
     std::shared_ptr<TimelineItemModel> m_activeTimelineModel;
     QElapsedTimer m_lastSave;
     QTimer m_autoSaveTimer;
@@ -249,11 +255,8 @@ private:
     /** @brief If true, means we are still opening Kdenlive, send messages to splash screen */
     bool m_loading{false};
     void saveRecentFiles();
+    /** @brief Something went wrong, stop loading file */
+    void abortLoading();
     /** @brief Project loading failed, ask user if he wants to open a backup */
     void requestBackup(const QString &errorMessage);
-    /** @brief WHen building a sequence producer, ensure we pass along all properties */
-    void passSequenceProperties(const QUuid &uuid, std::shared_ptr<Mlt::Producer> prod, Mlt::Tractor tractor, std::shared_ptr<TimelineItemModel> timelineModel,
-                                TimelineWidget *timelineWidget);
-    /** @brief Ensure sequences are correctly stored in our project model */
-    void checkProjectIntegrity();
 };
