@@ -8,6 +8,7 @@
 #include "core.h"
 #include "mainwindow.h"
 
+#include <KIO/DirectorySizeJob>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QAction>
@@ -22,6 +23,7 @@ PythonDependencyMessage::PythonDependencyMessage(QWidget *parent, AbstractPython
     , m_interface(interface)
 {
     setWordWrap(true);
+    hide();
     m_installAction = new QAction(i18n("Install missing dependencies"), this);
     m_abortAction = new QAction(i18n("Abort installation"), this);
     connect(m_abortAction, &QAction::triggered, m_interface, &AbstractPythonInterface::abortScript);
@@ -31,6 +33,8 @@ PythonDependencyMessage::PythonDependencyMessage(QWidget *parent, AbstractPython
         doShowMessage(message, KMessageWidget::Warning);
     });
 
+    connect(m_interface, &AbstractPythonInterface::setupWarning, this, [&](const QString &message) { doShowMessage(message, KMessageWidget::Warning); });
+
     connect(m_interface, &AbstractPythonInterface::checkVersionsResult, this, [&](const QStringList &list) {
         if (list.isEmpty()) {
             if (m_interface->featureName().isEmpty()) {
@@ -141,30 +145,76 @@ AbstractPythonInterface::~AbstractPythonInterface()
     delete m_scripts;
 }
 
-bool AbstractPythonInterface::checkSetup()
+bool AbstractPythonInterface::checkPython(bool useVenv, bool calculateSize)
 {
-    if (!(m_pyExec.isEmpty() || m_pip3Exec.isEmpty() || m_scripts->values().contains(QStringLiteral("")))) {
-        return true;
+    QStringList pythonPaths;
+    if (useVenv) {
+#ifdef Q_OS_WIN
+        const QString pythonPath = QStringLiteral("venv/Scripts/");
+#else
+        const QString pythonPath = QStringLiteral("venv/bin/");
+#endif
+        QDir pluginDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
+        if (!pluginDir.exists(pythonPath)) {
+            // Setup venv
+            if (!setupVenv()) {
+                return false;
+            }
+        }
+        pythonPaths << pluginDir.absoluteFilePath(pythonPath);
     }
 #ifdef Q_OS_WIN
-    m_pyExec = QStandardPaths::findExecutable(QStringLiteral("python"));
-    m_pip3Exec = QStandardPaths::findExecutable(QStringLiteral("pip"));
+    KdenliveSettings::setPythonPath(QStandardPaths::findExecutable(QStringLiteral("python"), pythonPaths));
+    KdenliveSettings::setPipPath(QStandardPaths::findExecutable(QStringLiteral("pip"), pythonPaths));
 #else
-    m_pyExec = QStandardPaths::findExecutable(QStringLiteral("python3"));
-    m_pip3Exec = QStandardPaths::findExecutable(QStringLiteral("pip3"));
+    KdenliveSettings::setPythonPath(QStandardPaths::findExecutable(QStringLiteral("python3"), pythonPaths));
+    KdenliveSettings::setPipPath(QStandardPaths::findExecutable(QStringLiteral("pip3"), pythonPaths));
 #endif
-    if (m_pyExec.isEmpty()) {
+    if (KdenliveSettings::pythonPath().isEmpty()) {
         Q_EMIT setupError(i18n("Cannot find python3, please install it on your system.\n"
                                "If already installed, check it is installed in a directory "
                                "listed in PATH environment variable"));
         return false;
     }
-    if (m_pip3Exec.isEmpty() && !m_disableInstall) {
+    if (KdenliveSettings::pipPath().isEmpty() && !m_disableInstall) {
         Q_EMIT setupError(i18n("Cannot find pip3, please install it on your system.\n"
                                "If already installed, check it is installed in a directory "
                                "listed in PATH environment variable"));
         return false;
     }
+    Q_EMIT gotPythonPath(i18n("Using python from %1", QFileInfo(KdenliveSettings::pythonPath()).absolutePath()));
+    if (calculateSize) {
+        // Calculate venv size
+        QDir pluginDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
+        if (pluginDir.cd(QStringLiteral("venv"))) {
+            KIO::DirectorySizeJob *job = KIO::directorySize(QUrl::fromLocalFile(pluginDir.absolutePath()));
+            connect(job, &KIO::DirectorySizeJob::result, this, &AbstractPythonInterface::gotFolderSize);
+        } else {
+            Q_EMIT gotPythonSize(i18n("No python venv found"));
+        }
+    }
+    qDebug() << "::: SETTING PYTHON PATH: " << KdenliveSettings::pythonPath();
+    return true;
+}
+
+void AbstractPythonInterface::gotFolderSize(KJob *job)
+{
+    auto *sourceJob = static_cast<KIO::DirectorySizeJob *>(job);
+    KIO::filesize_t total = sourceJob->totalSize();
+    if (sourceJob->totalFiles() == 0) {
+        total = 0;
+    }
+    Q_EMIT gotPythonSize(i18n("Python venv size: %1", KIO::convertSize(total)));
+}
+
+bool AbstractPythonInterface::checkSetup()
+{
+    if (!(KdenliveSettings::pythonPath().isEmpty() || KdenliveSettings::pipPath().isEmpty() || m_scripts->values().contains(QStringLiteral("")))) {
+        return true;
+    }
+    if (!checkPython(KdenliveSettings::usePythonVenv())) {
+        return false;
+    }
 
     for (int i = 0; i < m_scripts->count(); i++) {
         QString key = m_scripts->keys()[i];
@@ -176,6 +226,38 @@ bool AbstractPythonInterface::checkSetup()
     return true;
 }
 
+bool AbstractPythonInterface::setupVenv()
+{
+    // First check if python and venv are available
+    QString pyExec;
+#ifdef Q_OS_WIN
+    pyExec = QStandardPaths::findExecutable(QStringLiteral("python"));
+#else
+    pyExec = QStandardPaths::findExecutable(QStringLiteral("python3"));
+#endif
+    // Check that the system python is found
+    if (pyExec.isEmpty()) {
+        Q_EMIT setupError(i18n("Cannot find python3, please install it on your system.\n"
+                               "If already installed, check it is installed in a directory "
+                               "listed in PATH environment variable"));
+        return false;
+    }
+    const QString missingDeps = runScript(QStringLiteral("checkpackages.py"), {"virtualenv"}, QStringLiteral("--check"), false);
+    if (!missingDeps.isEmpty()) {
+        Q_EMIT setupError(i18n("Cannot find python virtualenv, please install it on your system."));
+        return false;
+    }
+    QDir pluginDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
+    pluginDir.mkpath(QStringLiteral("."));
+
+    QProcess envProcess;
+    QStringList args = {QStringLiteral("-m"), QStringLiteral("venv"), pluginDir.absoluteFilePath(QStringLiteral("venv"))};
+    qDebug() << "::: READY TO CREATE VENV: " << args;
+    envProcess.start(pyExec, args);
+    envProcess.waitForFinished(-1);
+    return true;
+}
+
 QString AbstractPythonInterface::locateScript(const QString &script)
 {
     QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("scripts/%1").arg(script));
@@ -195,18 +277,32 @@ void AbstractPythonInterface::addScript(const QString &script)
     m_scripts->insert(script, QStringLiteral(""));
 }
 
-void AbstractPythonInterface::checkDependencies()
+void AbstractPythonInterface::checkDependenciesConcurrently()
 {
-    if (m_dependenciesChecked) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QtConcurrent::run(this, &AbstractPythonInterface::checkDependencies, false);
+#else
+    QtConcurrent::run(&AbstractPythonInterface::checkDependencies, this, false);
+#endif
+}
+
+void AbstractPythonInterface::checkDependencies(bool force)
+{
+    if (!force && m_dependenciesChecked) {
         // Don't check twice if dependecies are satisfied
-        checkVersions(true);
+        if (m_missing.isEmpty()) {
+            checkVersions(true);
+        }
         return;
+    } else {
+        // Force check, reset flag
+        m_dependenciesChecked = false;
     }
+    m_missing.clear();
     QString output = runPackageScript(QStringLiteral("--check"));
     if (output.isEmpty()) {
         return;
     }
-    m_missing.clear();
     QStringList messages;
     for (auto i : m_dependencies.keys()) {
         if (output.contains(i)) {
@@ -218,9 +314,10 @@ void AbstractPythonInterface::checkDependencies()
             }
         }
     }
+    m_dependenciesChecked = true;
     if (messages.isEmpty()) {
-        m_dependenciesChecked = true;
         Q_EMIT dependenciesAvailable();
+        checkVersions(true);
     } else {
         Q_EMIT dependenciesMissing(messages);
     }
@@ -242,6 +339,18 @@ QStringList AbstractPythonInterface::missingDependencies(const QStringList &filt
 
 void AbstractPythonInterface::installMissingDependencies()
 {
+    if (!KdenliveSettings::usePythonVenv()) {
+        QDir pluginDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
+        if (KMessageBox::questionTwoActions(
+                pCore->window(),
+                i18n("Kdenlive can install the missing python modules in a virtual environement under %1.\nThis way, it won't touch your system libraries.",
+                     pluginDir.absoluteFilePath(QStringLiteral("venv"))),
+                i18n("Python environement"), KGuiItem(i18n("Use system install")),
+                KGuiItem(i18n("Use virtual environement (recommended)"))) == KMessageBox::SecondaryAction) {
+            KdenliveSettings::setUsePythonVenv(true);
+            checkPython(true, true);
+        }
+    }
     runPackageScript(QStringLiteral("--install"), true);
 }
 
@@ -349,7 +458,12 @@ QString AbstractPythonInterface::runPackageScript(const QString &mode, bool conc
 QString AbstractPythonInterface::runScript(const QString &script, QStringList args, const QString &firstarg, bool concurrent, bool packageFeedback)
 {
     QString scriptpath = m_scripts->value(script);
-    if (m_pyExec.isEmpty() || scriptpath.isEmpty()) {
+    if (KdenliveSettings::pythonPath().isEmpty() || scriptpath.isEmpty()) {
+        if (KdenliveSettings::pythonPath().isEmpty()) {
+            Q_EMIT setupError(i18n("Python exec not found"));
+        } else {
+            Q_EMIT setupError(i18n("Failed to find script file %1", script));
+        }
         return {};
     }
     if (concurrent && (firstarg == QLatin1String("--install") || firstarg == QLatin1String("--upgrade"))) {
@@ -376,12 +490,14 @@ QString AbstractPythonInterface::runScript(const QString &script, QStringList ar
         }
     }
     connect(this, &AbstractPythonInterface::abortScript, &scriptJob, &QProcess::kill, Qt::DirectConnection);
-    scriptJob.start(m_pyExec, args);
+    scriptJob.start(KdenliveSettings::pythonPath(), args);
     // Don't timeout
     scriptJob.waitForFinished(-1);
     if (!concurrent && (scriptJob.exitStatus() != QProcess::NormalExit || scriptJob.exitCode() != 0)) {
         qDebug() << "::::: WARNING ERRROR EXIT STATUS: " << scriptJob.exitCode();
-        KMessageBox::detailedError(pCore->window(), i18n("Error while running python3 script:\n %1", scriptpath), scriptJob.readAllStandardError());
+        const QString errorMessage = scriptJob.readAllStandardError();
+        Q_EMIT setupError(i18n("Error while running python3 script:\n %1\n%2", scriptpath, errorMessage));
+        qWarning() << " SCRIPT ERROR: " << errorMessage;
         return {};
     }
     if (script == QLatin1String("checkgpu.py")) {
@@ -391,3 +507,19 @@ QString AbstractPythonInterface::runScript(const QString &script, QStringList ar
     }
     return scriptJob.readAllStandardOutput();
 }
+
+bool AbstractPythonInterface::removePythonVenv()
+{
+    QDir pluginDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
+    if (!pluginDir.exists(QStringLiteral("venv")) || !pluginDir.absolutePath().contains(QStringLiteral("kdenlive"))) {
+        return false;
+    }
+    if (KMessageBox::warningContinueCancel(pCore->window(),
+                                           i18n("This will delete the python virtual environnment from:<br/><b>%1</b><br/>The environment will be recreated "
+                                                "and modules downloaded whenever you reenable the python virtual environnment.",
+                                                pluginDir.absoluteFilePath(QStringLiteral("venv")))) != KMessageBox::Continue) {
+        return false;
+    }
+    pluginDir.rmpath(QStringLiteral("venv"));
+    return true;
+}
