@@ -4,9 +4,12 @@
 */
 
 #include "renderrequest.h"
+#include "bin/projectitemmodel.h"
 #include "core.h"
 #include "doc/kdenlivedoc.h"
+#include "kdenlivesettings.h"
 #include "project/projectmanager.h"
+#include "renderpresets/renderpresetrepository.hpp"
 #include "utils/qstringutils.h"
 #include "xml/xml.hpp"
 
@@ -18,6 +21,20 @@
 #include <KMessageBox>
 #include <QInputDialog>
 
+// TODO:
+#include "doc/docundostack.hpp"
+#include <QUndoGroup>
+
+QStringList RenderRequest::argsByJob(const RenderJob &job)
+{
+    QStringList args = {QStringLiteral("delivery"), KdenliveSettings::meltpath(), job.playlistPath, QStringLiteral("--pid"),
+                        QString::number(QCoreApplication::applicationPid())};
+    if (!job.subtitlePath.isEmpty()) {
+        args << QStringLiteral("--subtitle") << job.subtitlePath;
+    }
+    return args;
+}
+
 RenderRequest::RenderRequest()
 {
     setBounds(-1, -1);
@@ -43,6 +60,26 @@ void RenderRequest::setPresetParams(const RenderPresetParams &params)
     m_presetParams = params;
 }
 
+void RenderRequest::loadPresetParams(const QString &profileName)
+{
+    std::unique_ptr<RenderPresetModel> &profile = RenderPresetRepository::get()->getPreset(profileName);
+    m_presetParams = profile->params();
+    m_presetParams.refreshX265Params();
+    QStringList presetDefaults = profile->defaultValues();
+
+    // Replace placeholders by default values
+    m_presetParams.replacePlaceholder(QLatin1String("%audioquality"), presetDefaults.at(2));
+    m_presetParams.replacePlaceholder(QLatin1String("%audiobitrate+'k'"), QStringLiteral("%1k").arg(presetDefaults.at(1)));
+    m_presetParams.replacePlaceholder(QLatin1String("%audiobitrate"), presetDefaults.at(1));
+    m_presetParams.replacePlaceholder(QLatin1String("%bitrate+'k'"), QStringLiteral("%1k").arg(presetDefaults.at(3)));
+    m_presetParams.replacePlaceholder(QLatin1String("%bitrate"), presetDefaults.at(3));
+
+    // Insert parameters of default speed
+    if (!presetDefaults.first().isEmpty() && presetDefaults.first().contains(QLatin1Char('='))) {
+        m_presetParams.insertFromString(presetDefaults.first(), false);
+    }
+}
+
 void RenderRequest::setDelayedRendering(bool enabled)
 {
     m_delayedRendering = enabled;
@@ -101,16 +138,17 @@ std::vector<RenderRequest::RenderJob> RenderRequest::process()
         dir.cd(QFileInfo(playlistPath).baseName());
         project->prepareRenderAssets(dir);
     }
+
     QString playlistContent =
         pCore->projectManager()->projectSceneList(project->url().adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile(), m_overlayData);
 
+    QDomDocument doc;
+    doc.setContent(playlistContent);
+
     if (m_delayedRendering) {
         project->restoreRenderAssets();
     }
 
-    QDomDocument doc;
-    doc.setContent(playlistContent);
-
     // Add autoclose to playlists
     KdenliveDoc::setAutoclosePlaylists(doc, pCore->currentTimelineId().toString());
 
@@ -176,20 +214,20 @@ std::vector<RenderRequest::RenderJob> RenderRequest::process()
         // set parameters
         setDocGeneralParams(sectionDoc, section.in, section.out);
 
-        createRenderJobs(jobs, sectionDoc, newPlaylistPath, outputPath, subtitleFile, currentUuid);
+        createRenderJobs(jobs, sectionDoc, newPlaylistPath, outputPath, subtitleFile);
     }
 
     return jobs;
 }
 
 void RenderRequest::createRenderJobs(std::vector<RenderJob> &jobs, const QDomDocument &doc, const QString &playlistPath, QString outputPath,
-                                     const QString &subtitlePath, const QUuid &uuid)
+                                     const QString &subtitlePath)
 {
     if (m_audioFilePerTrack) {
         if (m_delayedRendering) {
             addErrorMessage(i18n("Script rendering and multi track audio export can not be used together. Script will be saved without multi track export."));
         } else {
-            prepareMultiAudioFiles(jobs, doc, playlistPath, outputPath, uuid);
+            prepareMultiAudioFiles(jobs, doc, playlistPath, outputPath);
         }
     }
 
@@ -298,6 +336,8 @@ void RenderRequest::setDocGeneralParams(QDomDocument doc, int in, int out)
     consumer.setAttribute(QStringLiteral("in"), in);
     consumer.setAttribute(QStringLiteral("out"), out);
     consumer.setAttribute(QStringLiteral("mlt_service"), QStringLiteral("avformat"));
+    consumer.setAttribute(QStringLiteral("rescale"), KdenliveSettings::renderInterp().toUtf8().constData());
+    consumer.setAttribute(QStringLiteral("deinterlacer"), KdenliveSettings::renderDeinterlacer().toUtf8().constData());
 
     QMapIterator<QString, QString> it(m_presetParams);
 
@@ -380,8 +420,6 @@ std::vector<RenderRequest::RenderSection> RenderRequest::getGuideSections()
                     section.name = markers.at(i).comment();
                     section.in = markers.at(i).time().frames(fps);
                 }
-                section.name.replace(QLatin1Char('/'), QLatin1Char('_'));
-                section.name.replace(QLatin1Char('\\'), QLatin1Char('_'));
                 section.name = QStringUtils::getUniqueName(names, section.name);
                 names << section.name;
 
@@ -398,38 +436,20 @@ std::vector<RenderRequest::RenderSection> RenderRequest::getGuideSections()
     return sections;
 }
 
-void RenderRequest::prepareMultiAudioFiles(std::vector<RenderJob> &jobs, const QDomDocument &doc, const QString &playlistFile, const QString &targetFile,
-                                           const QUuid &uuid)
+void RenderRequest::prepareMultiAudioFiles(std::vector<RenderJob> &jobs, const QDomDocument &doc, const QString &playlistFile, const QString &targetFile)
 {
     int audioCount = 0;
     QDomNodeList orginalTractors = doc.elementsByTagName(QStringLiteral("tractor"));
     // process in reversed order to make file naming fit to UI
-    QStringList trackIds;
     for (int i = orginalTractors.size(); i >= 0; i--) {
         auto originalTracktor = orginalTractors.at(i).toElement();
-        const QUuid tractorUuid(Xml::getXmlProperty(originalTracktor, QStringLiteral("kdenlive:uuid")));
-        if (tractorUuid == uuid) {
-            // We found the current timeline tractor, list its tracks
-            QDomNodeList childTracks = originalTracktor.elementsByTagName(QStringLiteral("track"));
-            for (int j = childTracks.size(); j >= 0; j--) {
-                trackIds << childTracks.at(j).toElement().attribute(QStringLiteral("producer"));
-            }
-            break;
-        }
-    }
-
-    for (int i = orginalTractors.size(); i >= 0; i--) {
-        // Create a render job for each track, muting others
-        auto originalTracktor = orginalTractors.at(i).toElement();
-        const QString processedTrackId = originalTracktor.attribute(QStringLiteral("id"));
-        if (!trackIds.contains(processedTrackId)) {
-            continue;
-        }
         QString trackName = Xml::getXmlProperty(originalTracktor, QStringLiteral("kdenlive:track_name"));
-        bool originalIsAudio = Xml::getXmlProperty(originalTracktor, QStringLiteral("kdenlive:audio_track")).toInt() == 1;
-        if (!originalIsAudio) {
-            // Not an audio track, nothing to do
-            continue;
+
+        {
+            bool originalIsAudio = Xml::getXmlProperty(originalTracktor, QStringLiteral("kdenlive:audio_track")).toInt() == 1;
+            if (!originalIsAudio) {
+                continue;
+            }
         }
 
         // setup filenames
@@ -449,21 +469,11 @@ void RenderRequest::prepareMultiAudioFiles(std::vector<RenderJob> &jobs, const Q
 
         QDomNodeList tracktors = docCopy.elementsByTagName(QStringLiteral("tractor"));
         Q_ASSERT(tracktors.size() == orginalTractors.size());
-        QDomNodeList mainTracks = docCopy.elementsByTagName(QStringLiteral("tractor"));
+
         for (int j = 0; j < tracktors.size(); j++) {
             auto tractor = tracktors.at(j).toElement();
-            const QString currentId = tractor.attribute(QStringLiteral("id"));
-            if (!trackIds.contains(currentId)) {
-                // Not a track in current timeline
-                continue;
-            }
-            if (processedTrackId == currentId) {
-                // This is the track we want
-                continue;
-            }
             bool copyIsAudio = Xml::getXmlProperty(tractor, QStringLiteral("kdenlive:audio_track")).toInt() == 1;
             if (!copyIsAudio) {
-                // Not an audio track, leave as is
                 continue;
             }
             QDomNodeList tracks = tractor.elementsByTagName(QStringLiteral("track"));
