@@ -6,6 +6,7 @@
 #pragma once
 
 #include "bin/model/markerlistmodel.hpp"
+#include "doc/kdenlivedoc.h"
 #include "renderpresets/renderpresetmodel.hpp"
 
 class RenderRequest
@@ -27,6 +28,8 @@ public:
     void setBounds(int in, int out);
     void setOutputFile(const QString &filename);
     void setPresetParams(const RenderPresetParams &params);
+    /** @brief Load render params from a profile name */
+    void loadPresetParams(const QString &profileName);
     void setDelayedRendering(bool enabled);
     void setProxyRendering(bool enabled);
     void setEmbedSubtitles(bool enabled);
@@ -39,6 +42,8 @@ public:
 
     QStringList errorMessages();
 
+    static QStringList argsByJob(const RenderJob &job);
+
 private:
     struct RenderSection
     {
@@ -66,8 +71,7 @@ private:
     void setDocGeneralParams(QDomDocument doc, int in, int out);
     void setDocTwoPassParams(int pass, QDomDocument &doc, const QString &outputFile);
     std::vector<RenderSection> getGuideSections();
-    static void prepareMultiAudioFiles(std::vector<RenderJob> &jobs, const QDomDocument &doc, const QString &playlistFile, const QString &targetFile,
-                                       const QUuid &uuid);
+    static void prepareMultiAudioFiles(std::vector<RenderJob> &jobs, const QDomDocument &doc, const QString &playlistFile, const QString &targetFile);
 
     static QString createEmptyTempFile(const QString &extension);
 
@@ -81,8 +85,7 @@ private:
      *  There might be multiple jobs for one section for each pass in case of 2pass or each audio track in case of multi audio track export
      * @param jobs the vector to which the jobs will be added
      */
-    void createRenderJobs(std::vector<RenderJob> &jobs, const QDomDocument &doc, const QString &playlistPath, QString outputPath, const QString &subtitlePath,
-                          const QUuid &uuid);
+    void createRenderJobs(std::vector<RenderJob> &jobs, const QDomDocument &doc, const QString &playlistPath, QString outputPath, const QString &subtitlePath);
 
     void addErrorMessage(const QString &error);
 };
