@@ -13,8 +13,6 @@
 #include "profiles/profilerepository.hpp"
 #include "renderpresetrepository.hpp"
 
-#include <mlt++/MltRepository.h>
-
 #include <KLocalizedString>
 #include <KMessageWidget>
 #include <QDir>
@@ -33,6 +31,28 @@ QString RenderPresetParams::toString()
     return string.simplified();
 }
 
+void RenderPresetParams::insertFromString(const QString &params, bool overwrite)
+{
+    // split only at white spaces followed by a new parameter
+    // to avoid spliting values that contain whitespaces
+    static const QRegularExpression regexp(R"(\s+(?=\S*=))");
+
+    QStringList paramList = params.split(regexp, Qt::SkipEmptyParts);
+    for (QString param : paramList) {
+        if (!param.contains(QLatin1Char('='))) {
+            // invalid param, skip
+            continue;
+        }
+        const QString key = param.section(QLatin1Char('='), 0, 0);
+        const QString value = param.section(QLatin1Char('='), 1);
+        if (contains(key) && !overwrite) {
+            // don't overwrite existing params
+            continue;
+        }
+        insert(key, value);
+    }
+}
+
 void RenderPresetParams::replacePlaceholder(const QString &placeholder, const QString &newValue)
 {
     RenderPresetParams newParams;
@@ -306,29 +326,6 @@ void RenderPresetModel::checkPreset()
         }
     }
 
-    if (hasParam(QStringLiteral("properties"))) {
-        // This is a native MLT render profile, check the file for codec
-        QString presetName = getParam(QStringLiteral("properties"));
-        presetName.prepend(QStringLiteral("consumer/avformat/"));
-        std::unique_ptr<Mlt::Properties> presets(pCore->getMltRepository()->presets());
-        std::unique_ptr<Mlt::Properties> preset(new Mlt::Properties(mlt_properties(presets->get_data(presetName.toUtf8().constData()))));
-        const QString format = QString(preset->get("f")).toLower();
-        if (!format.isEmpty() && !supportedFormats.contains(format)) {
-            m_errors = i18n("Unsupported video format: %1", format);
-            return;
-        }
-        const QString vcodec = QString(preset->get("vcodec")).toLower();
-        if (!vcodec.isEmpty() && !vcodecs.contains(vcodec)) {
-            m_errors = i18n("Unsupported video codec: %1", vcodec);
-            return;
-        }
-        const QString acodec = QString(preset->get("acodec")).toLower();
-        if (!acodec.isEmpty() && !acodecs.contains(acodec)) {
-            m_errors = i18n("Unsupported audio codec: %1", acodec);
-            return;
-        }
-    }
-
     // Make sure the selected preset uses an installed avformat codec / format
     QString format;
     format = getParam(QStringLiteral("f")).toLower();
@@ -409,14 +406,8 @@ QDomElement RenderPresetModel::toXml()
 void RenderPresetModel::setParams(const QString &params)
 {
     m_params.clear();
-    // split only at white spaces followed by a new parameter
-    // to avoid spliting values that contain whitespaces
-    static const QRegularExpression regexp(R"(\s+(?=\S*=))");
+    m_params.insertFromString(params, true);
 
-    QStringList paramList = params.split(regexp, Qt::SkipEmptyParts);
-    for (QString param : paramList) {
-        m_params.insert(param.section(QLatin1Char('='), 0, 0), param.section(QLatin1Char('='), 1));
-    }
     if (!hasParam(QStringLiteral("f")) && !m_extension.isEmpty() && RenderPresetRepository::supportedFormats().contains(m_extension)) {
         m_params.insert(QStringLiteral("f"), m_extension);
     }
@@ -431,6 +422,16 @@ RenderPresetParams RenderPresetModel::params(QStringList removeParams) const
     return newParams;
 }
 
+QStringList RenderPresetModel::defaultValues() const
+{
+    QString defaultSpeedParams;
+    QStringList presetSpeeds = speeds();
+    if (!presetSpeeds.isEmpty() && m_defaultSpeedIndex < presetSpeeds.count()) {
+        defaultSpeedParams = presetSpeeds.at(m_defaultSpeedIndex);
+    }
+    return {defaultSpeedParams, m_defaultABitrate, m_defaultAQuality, m_defaultVBitrate, m_defaultVQuality};
+}
+
 QString RenderPresetModel::extension() const
 {
     if (!m_extension.isEmpty()) {
