@@ -20,6 +20,7 @@ public:
     enum RateControl { Unknown = 0, Average, Constant, Quality, Constrained };
 
     QString toString();
+    void insertFromString(const QString &params, bool overwrite);
     void replacePlaceholder(const QString &placeholder, const QString &newValue);
     void refreshX265Params();
     RateControl videoRateControl() const;
@@ -67,6 +68,8 @@ public:
     QString defaultVBitrate() const;
     QStringList videoQualities() const;
     QString defaultVQuality() const;
+    /** @brief Returns a list of all default values for this profile (speed, aBitrate, aQuality, vBitrate, vQuality */
+    QStringList defaultValues() const;
     bool editable() const;
     bool isManual() const;
 
