@@ -1,6 +1,6 @@
 /*
-   SPDX-FileCopyrightText: 2017 Nicolas Carion
-   SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+    SPDX-FileCopyrightText: 2017 Nicolas Carion
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "meltBuilder.hpp"
@@ -10,7 +10,6 @@
 #include "../trackmodel.hpp"
 #include "../undohelper.hpp"
 #include "bin/bin.h"
-#include "bin/projectclip.h"
 #include "bin/projectitemmodel.h"
 #include "core.h"
 #include "kdenlivesettings.h"
@@ -40,7 +39,7 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                             Fun &undo, Fun &redo, bool audioTrack, const QString &originalDecimalPoint, int playlist,
                             const QList<Mlt::Transition *> &compositions, QProgressDialog *progressDialog = nullptr);
 
-bool loadProjectBin(Mlt::Tractor tractor, const QUuid &activeUuid, QProgressDialog *progressDialog)
+bool loadProjectBin(Mlt::Tractor tractor, QProgressDialog *progressDialog)
 {
     Fun undo = []() { return true; };
     Fun redo = []() { return true; };
@@ -48,8 +47,7 @@ bool loadProjectBin(Mlt::Tractor tractor, const QUuid &activeUuid, QProgressDial
     QStringList expandedFolders;
     int zoomLevel = -1;
     binIdCorresp.clear();
-    m_notesLog.clear();
-    QList<QUuid> brokenSequences = pCore->projectItemModel()->loadBinPlaylist(&tractor, binIdCorresp, expandedFolders, activeUuid, zoomLevel, progressDialog);
+    QList<QUuid> brokenSequences = pCore->projectItemModel()->loadBinPlaylist(&tractor, binIdCorresp, expandedFolders, zoomLevel, progressDialog);
     if (!brokenSequences.isEmpty()) {
         KMessageBox::error(qApp->activeWindow(), i18n("Found an invalid sequence clip in Bin"));
         return false;
@@ -77,6 +75,7 @@ bool constructTimelineFromTractor(const std::shared_ptr<TimelineItemModel> &time
     // First, we destruct the previous tracks
     timeline->requestReset(undo, redo);
     m_errorMessage.clear();
+    m_notesLog.clear();
     bool useMappedIds = true;
 
     QStringList expandedFolders;
@@ -85,7 +84,7 @@ bool constructTimelineFromTractor(const std::shared_ptr<TimelineItemModel> &time
         int zoomLevel = -1;
         if (timeline->uuid() == pCore->currentTimelineId()) {
             binIdCorresp.clear();
-            projectModel->loadBinPlaylist(&tractor, binIdCorresp, expandedFolders, timeline->uuid(), zoomLevel, progressDialog);
+            projectModel->loadBinPlaylist(&tractor, binIdCorresp, expandedFolders, zoomLevel, progressDialog);
         } else {
             projectModel->loadTractorPlaylist(tractor, binIdCorresp);
         }
@@ -333,10 +332,11 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
     // First, we destruct the previous tracks
     timeline->requestReset(undo, redo);
     m_errorMessage.clear();
+    m_notesLog.clear();
     QStringList expandedFolders;
     int zoomLevel = -1;
     if (timeline->uuid() == pCore->currentTimelineId()) {
-        pCore->projectItemModel()->loadBinPlaylist(&tractor, binIdCorresp, expandedFolders, timeline->uuid(), zoomLevel, progressDialog);
+        pCore->projectItemModel()->loadBinPlaylist(&tractor, binIdCorresp, expandedFolders, zoomLevel, progressDialog);
     }
     QStringList foldersToExpand;
     // Find updated ids for expanded folders
@@ -503,8 +503,7 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
         int compoId;
         int aTrack = t->get_a_track();
         if (!timeline->isTrack(timeline->getTrackIndexFromPosition(t->get_b_track() - 1))) {
-            QString tcInfo = QString("<a href=\"%1!%2\">%3</a>")
-                                 .arg(timeline->uuid().toString(), QString::number(t->get_in()), pCore->timecode().getTimecodeFromFrames(t->get_in()));
+            QString tcInfo = QString("<a href=\"%1\">%2</a>").arg(QString::number(t->get_in()), pCore->timecode().getTimecodeFromFrames(t->get_in()));
             m_notesLog << i18n("%1 Composition (%2) with invalid track reference found and removed.", tcInfo, t->get("id"));
             m_errorMessage << i18n("Invalid composition %1 found on track %2 at %3, compositing with track %4.", t->get("id"), t->get_b_track(),
                                    pCore->timecode().getTimecodeFromFrames(t->get_in()), t->get_a_track());
@@ -512,9 +511,9 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
         }
         if (aTrack > tractor.count()) {
             int tid = timeline->getTrackIndexFromPosition(t->get_b_track() - 1);
-            const QString tcInfo = QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                       .arg(timeline->uuid().toString(), QString::number(t->get_in()), QString::number(timeline->getTrackPosition(tid) + 1),
-                                            timeline->getTrackTagById(tid), pCore->timecode().getTimecodeFromFrames(t->get_in()));
+            QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                 .arg(QString::number(t->get_in()), QString::number(timeline->getTrackPosition(tid) + 1), timeline->getTrackTagById(tid),
+                                      pCore->timecode().getTimecodeFromFrames(t->get_in()));
             m_notesLog << i18n("%1 Composition (%2) with invalid track reference found and removed.", tcInfo, t->get("id"));
             m_errorMessage << i18n("Invalid composition %1 found on track %2 at %3, compositing with track %4.", t->get("id"), t->get_b_track(),
                                    pCore->timecode().getTimecodeFromFrames(t->get_in()), t->get_a_track());
@@ -526,9 +525,9 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
             if (pos > 0 && videoTracksIndexes.at(pos - 1) != aTrack) {
                 t->set("force_track", 1);
                 int tid = timeline->getTrackIndexFromPosition(t->get_b_track() - 1);
-                const QString tcInfo = QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                           .arg(timeline->uuid().toString(), QString::number(t->get_in()), QString::number(timeline->getTrackPosition(tid) + 1),
-                                                timeline->getTrackTagById(tid), pCore->timecode().getTimecodeFromFrames(t->get_in()));
+                QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                     .arg(QString::number(t->get_in()), QString::number(timeline->getTrackPosition(tid) + 1), timeline->getTrackTagById(tid),
+                                          pCore->timecode().getTimecodeFromFrames(t->get_in()));
                 m_notesLog << i18n("%1 Composition was not applied on expected track, manually enforce the track.", tcInfo);
                 m_errorMessage << i18n("Incorrect composition %1 found on track %2 at %3, compositing with track %4 was set to forced track.", t->get("id"),
                                        t->get_b_track(), pCore->timecode().getTimecodeFromFrames(t->get_in()), t->get_a_track());
@@ -540,9 +539,9 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
         if (!compositionOk) {
             // timeline->requestItemDeletion(compoId, false);
             int tid = timeline->getTrackIndexFromPosition(t->get_b_track() - 1);
-            const QString tcInfo = QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                       .arg(timeline->uuid().toString(), QString::number(t->get_in()), QString::number(timeline->getTrackPosition(tid) + 1),
-                                            timeline->getTrackTagById(tid), pCore->timecode().getTimecodeFromFrames(t->get_in()));
+            QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                 .arg(QString::number(t->get_in()), QString::number(timeline->getTrackPosition(tid) + 1), timeline->getTrackTagById(tid),
+                                      pCore->timecode().getTimecodeFromFrames(t->get_in()));
             m_notesLog << i18n("%1 Invalid composition found and removed.", tcInfo);
             m_errorMessage << i18n("Invalid composition %1 found on track %2 at %3.", t->get("id"), t->get_b_track(),
                                    pCore->timecode().getTimecodeFromFrames(t->get_in()));
@@ -566,21 +565,11 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
     }
     if (!qEnvironmentVariableIsSet("MLT_TESTS")) {
         if (!m_notesLog.isEmpty()) {
+            m_notesLog.prepend(i18n("Errors found when opening project file (%1)", QDateTime::currentDateTime().toString()));
+            pCore->projectManager()->slotAddTextNote(m_notesLog.join("<br/>"));
             if (projectErrors) {
                 *projectErrors = true;
             }
-        }
-    }
-    timeline->isLoading = false;
-    return true;
-}
-
-void checkProjectWarnings()
-{
-    if (!qEnvironmentVariableIsSet("MLT_TESTS")) {
-        if (!m_notesLog.isEmpty()) {
-            m_notesLog.prepend(i18n("Errors found when opening project file (%1)", QDateTime::currentDateTime().toString()));
-            pCore->projectManager()->slotAddTextNote(m_notesLog.join("<br/>"));
             KMessageBox::detailedError(
                 qApp->activeWindow(),
                 i18n("Some errors were detected in the project file.\nThe project was modified to fix the conflicts. Changes made to the "
@@ -590,6 +579,8 @@ void checkProjectWarnings()
             KMessageBox::error(qApp->activeWindow(), m_errorMessage.join("\n"), i18n("Problems found in your project file"));
         }
     }
+    timeline->isLoading = false;
+    return true;
 }
 
 bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, int tid, bool useMappedIds, const QString trackTag, Mlt::Tractor &track,
@@ -658,9 +649,9 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
             if (cid1 > 0 && cid2 > 0) {
                 if (timeline->getClipSubPlaylistIndex(cid1) == 1) {
                     // Delete clip
-                    const QString tcInfo = QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                               .arg(timeline->uuid().toString(), QString::number(in), QString::number(timeline->getTrackPosition(tid) + 1),
-                                                    timeline->getTrackTagById(tid), pCore->timecode().getTimecodeFromFrames(timeline->getClipPosition(cid1)));
+                    QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                         .arg(QString::number(in), QString::number(timeline->getTrackPosition(tid) + 1), timeline->getTrackTagById(tid),
+                                              pCore->timecode().getTimecodeFromFrames(timeline->getClipPosition(cid1)));
                     m_notesLog << i18n("Incorrect Mix, clip %1 was removed at %2.", timeline->getClipName(cid1), tcInfo);
                     m_errorMessage << i18n("Incorrect mix found on track %1 at %2, clip %3 removed.", timeline->getTrackTagById(tid),
                                            pCore->timecode().getTimecodeFromFrames(timeline->getClipPosition(cid1)), timeline->getClipName(cid1));
@@ -668,9 +659,9 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
 
                 } else if (timeline->getClipSubPlaylistIndex(cid2) == 1) {
                     // Delete clip
-                    const QString tcInfo = QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                               .arg(timeline->uuid().toString(), QString::number(in), QString::number(timeline->getTrackPosition(tid) + 1),
-                                                    timeline->getTrackTagById(tid), pCore->timecode().getTimecodeFromFrames(timeline->getClipPosition(cid2)));
+                    QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                         .arg(QString::number(in), QString::number(timeline->getTrackPosition(tid) + 1), timeline->getTrackTagById(tid),
+                                              pCore->timecode().getTimecodeFromFrames(timeline->getClipPosition(cid2)));
                     m_notesLog << i18n("Incorrect Mix, clip %1 was removed at %2.", timeline->getClipName(cid2), tcInfo);
                     m_errorMessage << i18n("Incorrect mix found at track %1 at %2, clip %3 removed.", timeline->getTrackTagById(tid),
                                            pCore->timecode().getTimecodeFromFrames(timeline->getClipPosition(cid2)), timeline->getClipName(cid2));
@@ -720,7 +711,6 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                             const QList<Mlt::Transition *> &compositions, QProgressDialog *progressDialog)
 {
     int max = track.count();
-    const QString sequenceBinId = pCore->projectItemModel()->getSequenceId(timeline->uuid());
     for (int i = 0; i < max; i++) {
         if (track.is_blank(i)) {
             continue;
@@ -750,37 +740,10 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                 }
                 const QString service = clip->parent().get("mlt_service");
                 QString resource = service == QLatin1String("timewarp") ? clip->parent().get("warp_resource") : clip->parent().get("resource");
+
                 if (!useMappedIds || binIdCorresp.size() == 0 || (clip->parent().get_int("kdenlive:producer_type") == ClipType::Timeline)) {
                     // Currently "sequence" clips inserted in timeline are cuts of the bin clip, so it's kdenlive id is changed in loadBinPlaylist
-                    if (clip->parent().get_int("kdenlive:producer_type") == ClipType::Timeline && binIdCorresp.count(clipId) > 0 &&
-                        !clip->parent().property_exists("_kdenlive_processed")) {
-                        binId = binIdCorresp.at(clipId);
-                    } else {
-                        binId = clipId;
-                    }
-                    // Ensure we don't try to embed a sequence into itself
-                    if (binId == sequenceBinId) {
-                        // Trying to embed a sequence into itself, drop
-                        const QString tcInfo =
-                            QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                .arg(timeline->uuid().toString(), QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
-                                     pCore->timecode().getTimecodeFromFrames(position));
-                        m_notesLog << i18n("%1 Timeline clip (%2) without bin reference found and removed.", tcInfo, clip->parent().get("id"));
-                        m_errorMessage << i18n("Project corrupted. Clip %1 (%2) not found in project bin.", clip->parent().get("id"), clipId);
-                        continue;
-                    }
-                    // Check that the sequence clip exists
-                    auto binClip = pCore->projectItemModel()->getClipByBinID(binId);
-                    if (binClip == nullptr || binClip->getProducerIntProperty("kdenlive:producer_type") != clip->parent().get_int("kdenlive:producer_type")) {
-                        // Sequence clip not found, error out
-                        const QString tcInfo =
-                            QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                .arg(timeline->uuid().toString(), QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
-                                     pCore->timecode().getTimecodeFromFrames(position));
-                        m_notesLog << i18n("%1 Timeline clip (%2) without bin reference found and removed.", tcInfo, clip->parent().get("id"));
-                        m_errorMessage << i18n("Project corrupted. Clip %1 (%2) not found in project bin.", clip->parent().get("id"), clipId);
-                        continue;
-                    }
+                    binId = clipId;
                 } else if (binIdCorresp.count(clipId) == 0) {
                     if (clip->property_exists("kdenlive:remove")) {
                         // Clip was marked for deletion
@@ -789,10 +752,9 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                     // Project was somehow corrupted
                     qWarning() << "can't find clip with id: " << clipId << "in bin playlist";
                     QStringList fixedId = pCore->projectItemModel()->getClipByUrl(QFileInfo(resource));
-                    const QString tcInfo =
-                        QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                            .arg(timeline->uuid().toString(), QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
-                                 pCore->timecode().getTimecodeFromFrames(position));
+                    QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                         .arg(QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
+                                              pCore->timecode().getTimecodeFromFrames(position));
                     if (!fixedId.isEmpty()) {
                         binId = fixedId.first();
                         m_notesLog << i18n("%1 Timeline clip (%2) with incorrect bin reference found and recovered.", tcInfo, clip->parent().get("id"));
@@ -850,10 +812,9 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                         }
                         if (startMixToFind || endMixToFind) {
                             // A mix for this clip is missing
-                            const QString tcInfo =
-                                QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                    .arg(timeline->uuid().toString(), QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
-                                         pCore->timecode().getTimecodeFromFrames(position));
+                            QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                                 .arg(QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
+                                                      pCore->timecode().getTimecodeFromFrames(position));
                             // Try to resize clip and put it on playlist 0
                             if (hasEndMix && endMixToFind) {
                                 // Find last empty frame on playlist 0
@@ -913,18 +874,20 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                     } else {
                         // Check if playlist 0 is available
                         enforceTopPlaylist = timeline->trackIsAvailable(tid, position, duration, 0);
-                        const QString tcInfo =
-                            QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                .arg(timeline->uuid().toString(), QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
-                                     pCore->timecode().getTimecodeFromFrames(position));
                         if (enforceTopPlaylist) {
                             m_errorMessage << i18n("Clip %1 on incorrect subtrack found and fixed on track %2 at %3.", clip->parent().get("id"), trackTag,
                                                    pCore->timecode().getTimecodeFromFrames(position));
+                            QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                                 .arg(QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
+                                                      pCore->timecode().getTimecodeFromFrames(position));
                             m_notesLog << i18n("%1 Clip (%2) on incorrect subtrack found and fixed / %3", tcInfo, clip->parent().get("id"),
                                                QString::number(tid));
                         } else {
                             m_errorMessage << i18n("Clip %1 on incorrect subtrack found on track %2 at %3.", clip->parent().get("id"), trackTag,
                                                    pCore->timecode().getTimecodeFromFrames(position));
+                            QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                                 .arg(QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
+                                                      pCore->timecode().getTimecodeFromFrames(position));
                             m_notesLog << i18n("%1 Clip (%2) with incorrect subplaylist found", tcInfo, clip->parent().get("id"));
                         }
                     }
@@ -938,9 +901,9 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                 timeline->requestItemDeletion(cid, false);
                 m_errorMessage << i18n("Invalid clip %1 found on track %2 at %3.", clip->parent().get("id"), track.get("id"),
                                        pCore->timecode().getTimecodeFromFrames(position));
-                const QString tcInfo = QString("<a href=\"%1!%2?%3\">%4 %5</a>")
-                                           .arg(timeline->uuid().toString(), QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1),
-                                                trackTag, pCore->timecode().getTimecodeFromFrames(position));
+                QString tcInfo = QString("<a href=\"%1?%2\">%3 %4</a>")
+                                     .arg(QString::number(position), QString::number(timeline->getTrackPosition(tid) + 1), trackTag,
+                                          pCore->timecode().getTimecodeFromFrames(position));
                 m_notesLog << i18n("%1 Invalid clip (%2) found and removed", tcInfo, clip->parent().get("id"));
                 continue;
             }
@@ -949,7 +912,6 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
         case mlt_service_tractor_type: {
             // TODO This is a nested timeline
             qWarning() << "nested timelines not yet implemented";
-            Q_ASSERT(false);
             break;
         }
         default:
