@@ -145,10 +145,10 @@ void ClipModel::registerClipToBin(std::shared_ptr<Mlt::Producer> service, bool r
     binClip->registerService(m_parent, m_id, std::move(service), registerProducer);
 }
 
-void ClipModel::deregisterClipToBin(const QUuid &uuid)
+void ClipModel::deregisterClipToBin()
 {
     std::shared_ptr<ProjectClip> binClip = pCore->projectItemModel()->getClipByBinID(m_binClipId);
-    binClip->deregisterTimelineClip(m_id, isAudioOnly(), uuid);
+    binClip->deregisterTimelineClip(m_id, isAudioOnly());
 }
 
 ClipModel::~ClipModel() = default;
@@ -284,7 +284,7 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
                 }
                 return true;
             }
-            qDebug() << "============\n+++++++++++++++++\nREVRSE TRACK OP FAILED FOR: " << m_id << "\n\n++++++++++++++++";
+            qDebug() << "============\n+++++++++++++++++\nREVRSE TRACK OP FAILED\n\n++++++++++++++++";
             return false;
         };
         Fun preProcess = [this, roles, oldIn, oldOut, newIn = m_position, newOut = m_position + getOut() - getIn(), right, logUndo]() {
@@ -1520,9 +1520,9 @@ const QString ClipModel::clipThumbPath()
     return QString();
 }
 
-void ClipModel::switchBinReference(const QString newId, const QUuid &uuid)
+void ClipModel::switchBinReference(const QString newId)
 {
-    deregisterClipToBin(uuid);
+    deregisterClipToBin();
     m_binClipId = newId;
     refreshProducerFromBin(-1);
     registerClipToBin(getProducer(), false);
