@@ -111,7 +111,7 @@ public:
     void allSnaps(std::vector<int> &snaps, int offset = 0) const;
 
     /** @brief Replace the bin producer with another bin clip */
-    void switchBinReference(const QString newId, const QUuid &uuid);
+    void switchBinReference(const QString newId);
 
 protected:
     /** @brief helper functions that creates the lambda */
@@ -128,7 +128,7 @@ public:
     const QString &binId() const;
 
     void registerClipToBin(std::shared_ptr<Mlt::Producer> service, bool registerProducer);
-    void deregisterClipToBin(const QUuid &uuid);
+    void deregisterClipToBin();
 
     bool addEffect(const QString &effectId);
     bool copyEffect(const QUuid &uuid, const std::shared_ptr<EffectStackModel> &stackModel, int rowId);
